@@ -420,7 +420,7 @@ function setup_mgmt_network() {
 
 # start_trove() - Start running processes, including screen
 function start_trove {
-    if [[ ${TROVE_USE_MOD_WSGI}" == TRUE" ]]; then
+    if [[ "${TROVE_USE_MOD_WSGI}" == "TRUE" ]]; then
         echo "Restarting Apache server ..."
         enable_apache_site trove-api
         restart_apache_server
@@ -435,7 +435,7 @@ function start_trove {
 function stop_trove {
     # Kill the trove screen windows
     local serv
-    if [[ ${TROVE_USE_MOD_WSGI} == "TRUE" ]]; then
+    if [[ "${TROVE_USE_MOD_WSGI}" == "TRUE" ]]; then
         echo "Disabling Trove API in Apache"
         disable_apache_site trove-api
     else
@@ -527,19 +527,18 @@ function create_registry_container {
     container=$(sudo docker ps -a --format "{{.Names}}" --filter name=registry)
     if [ -z $container ]; then
         sudo docker run -d --net=host -e REGISTRY_HTTP_ADDR=0.0.0.0:4000 --restart=always -v /opt/trove_registry/:/var/lib/registry --name registry quay.io/openstack.trove/registry:2
-        for img in {"mysql:5.7","mysql:8.0","mariadb:10.4","postgres:12"};
+        for img in {"mysql:8.4","mariadb:11.4","postgres:17"};
         do
         sudo docker pull quay.io/openstack.trove/${img} && sudo docker tag quay.io/openstack.trove/${img} 127.0.0.1:4000/trove-datastores/${img} && sudo docker push 127.0.0.1:4000/trove-datastores/${img}
         done
         pushd $DEST/trove/backup
         # build backup images
-        sudo docker build --network host -t 127.0.0.1:4000/trove-datastores/db-backup-mysql:5.7 --build-arg DATASTORE=mysql --build-arg DATASTORE_VERSION=5.7 .
-        sudo docker build --network host -t 127.0.0.1:4000/trove-datastores/db-backup-mysql:8.0 --build-arg DATASTORE=mysql --build-arg DATASTORE_VERSION=8.0 .
-        sudo docker build --network host -t 127.0.0.1:4000/trove-datastores/db-backup-mariadb:10.4 --build-arg DATASTORE=mariadb --build-arg DATASTORE_VERSION=10.4 .
-        sudo docker build --network host -t 127.0.0.1:4000/trove-datastores/db-backup-postgresql:12 --build-arg DATASTORE=postgresql --build-arg DATASTORE_VERSION=12 .
+        sudo docker build --network host -t 127.0.0.1:4000/trove-datastores/db-backup-mysql:8.4 --build-arg DATASTORE=mysql --build-arg DATASTORE_VERSION=8.4 .
+        sudo docker build --network host -t 127.0.0.1:4000/trove-datastores/db-backup-mariadb:11.4 --build-arg DATASTORE=mariadb --build-arg DATASTORE_VERSION=11.4 .
+        sudo docker build --network host -t 127.0.0.1:4000/trove-datastores/db-backup-postgresql:17 --build-arg DATASTORE=postgresql --build-arg DATASTORE_VERSION=17 .
         popd
         # push backup images
-        for backupimg in {"db-backup-mysql:5.7","db-backup-mysql:8.0","db-backup-mariadb:10.4","db-backup-postgresql:12"};
+        for backupimg in {"db-backup-mysql:8.4","db-backup-mariadb:11.4","db-backup-postgresql:17"};
         do
         sudo docker push 127.0.0.1:4000/trove-datastores/${backupimg}
         done
@@ -643,7 +642,7 @@ function config_nova_keypair {
     fi
 
     echo "Creating Trove management keypair ${TROVE_MGMT_KEYPAIR_NAME}"
-    openstack --os-cloud trove keypair create --public-key ${SSH_DIR}/id_rsa.pub ${TROVE_MGMT_KEYPAIR_NAME}
+    openstack --os-cloud trove keypair create --user trove --public-key ${SSH_DIR}/id_rsa.pub ${TROVE_MGMT_KEYPAIR_NAME}
 
     iniset $TROVE_CONF DEFAULT nova_keypair ${TROVE_MGMT_KEYPAIR_NAME}
 }
