@@ -13,15 +13,12 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 #
-from trove.common import cfg
-
-CONF = cfg.CONF
 
 url_ref = {
     "type": "string",
     "minLength": 8,
-    "pattern": 'http[s]?://(?:[a-zA-Z]|[0-9]|[$-_@.&+]|[!*\(\),]'
-               '|(?:%[0-9a-fA-F][0-9a-fA-F]))+'
+    "pattern": r'http[s]?://(?:[a-zA-Z]|[0-9]|[$-_@.&+]|[!*\(\),]'
+               r'|(?:%[0-9a-fA-F][0-9a-fA-F]))+'
 }
 
 boolean_string = {
@@ -53,7 +50,7 @@ configuration_positive_integer = {
     "type": "string",
     "maxLength": 40,
     "minLength": 1,
-    "pattern": "^[0-9]+$"
+    "pattern": "^0*[1-9]+[0-9]*$"
 }
 
 configuration_non_empty_string = {
@@ -75,7 +72,16 @@ volume_size = {
     "oneOf": [
         {
             "type": "integer",
-            "minimum": 0
+            "minimum": 1
+        },
+        configuration_positive_integer]
+}
+
+number_of_nodes = {
+    "oneOf": [
+        {
+            "type": "integer",
+            "minimum": 1
         },
         configuration_positive_integer]
 }
@@ -83,7 +89,7 @@ volume_size = {
 host_string = {
     "type": "string",
     "minLength": 1,
-    "pattern": "^[%]?[\w(-).]*[%]?$"
+    "pattern": r"^[%]?[\w(-).]*[%]?$"
 }
 
 name_string = {
@@ -100,19 +106,39 @@ uuid = {
                "-([0-9a-fA-F]){4}-([0-9a-fA-F]){12}$"
 }
 
+ip_address_v4 = {
+    "type": "string",
+    "minLength": 7,
+    "maxLength": 15,
+    "pattern": r"^(?:[0-9]{1,3}\.){3}[0-9]{1,3}$"
+}
+
 volume = {
     "type": "object",
     "required": ["size"],
     "properties": {
         "size": volume_size,
-        "required": True
+        "type": {
+            "oneOf": [
+                non_empty_string,
+                {"type": "null"}
+            ]
+        }
     }
 }
 
 nics = {
     "type": "array",
+    "maxItems": 1,
     "items": {
         "type": "object",
+        "additionalProperties": False,
+        "properties": {
+            "net-id": uuid,
+            "network_id": uuid,
+            "subnet_id": uuid,
+            "ip_address": ip_address_v4
+        }
     }
 }
 
@@ -253,62 +279,93 @@ cluster = {
                                 "nics": nics,
                                 "availability_zone": non_empty_string,
                                 "modules": module_list,
+                                "region_name": non_empty_string
                             }
                         }
                     },
-                    "locality": non_empty_string
-                }
-            }
-        }
-    },
-    "add_shard": {
-        "type": "object",
-        "required": ["add_shard"],
-        "additionalProperties": True,
-        "properties": {
-            "add_shard": {
-                "type": "object"
-            }
-        }
-    },
-    "grow": {
-        "type": "object",
-        "required": ["grow"],
-        "additionalProperties": True,
-        "properties": {
-            "grow": {
-                "type": "array",
-                "items": {
-                    "type": "object",
-                    "required": ["flavorRef"],
-                    "additionalProperties": True,
-                    "properties": {
-                        "name": non_empty_string,
-                        "flavorRef": flavorref,
-                        "volume": volume,
-                        "nics": nics,
-                        "availability_zone": non_empty_string,
-                        "modules": module_list,
-                        "related_to": non_empty_string,
-                        "type": non_empty_string
+                    "locality": non_empty_string,
+                    "extended_properties": {
+                        "type": "object",
+                        "additionalProperties": True,
+                        "properties": {
+                            "num_configsvr": number_of_nodes,
+                            "num_mongos": number_of_nodes,
+                            "configsvr_volume_size": volume_size,
+                            "configsvr_volume_type": non_empty_string,
+                            "mongos_volume_size": volume_size,
+                            "mongos_volume_type": non_empty_string
+                        }
                     }
                 }
             }
         }
     },
-    "shrink": {
-        "type": "object",
-        "required": ["shrink"],
-        "additionalProperties": True,
-        "properties": {
-            "shrink": {
-                "type": "array",
-                "items": {
+    "action": {
+        "add_shard": {
+            "type": "object",
+            "required": ["add_shard"],
+            "additionalProperties": True,
+            "properties": {
+                "add_shard": {
+                    "type": "object"
+                }
+            }
+        },
+        "grow": {
+            "type": "object",
+            "required": ["grow"],
+            "additionalProperties": True,
+            "properties": {
+                "grow": {
+                    "type": "array",
+                    "items": {
+                        "type": "object",
+                        "required": ["flavorRef"],
+                        "additionalProperties": True,
+                        "properties": {
+                            "name": non_empty_string,
+                            "flavorRef": flavorref,
+                            "volume": volume,
+                            "nics": nics,
+                            "availability_zone": non_empty_string,
+                            "modules": module_list,
+                            "related_to": non_empty_string,
+                            "type": non_empty_string,
+                            "region_name": non_empty_string
+                        }
+                    }
+                }
+            }
+        },
+        "shrink": {
+            "type": "object",
+            "required": ["shrink"],
+            "additionalProperties": True,
+            "properties": {
+                "shrink": {
+                    "type": "array",
+                    "items": {
+                        "type": "object",
+                        "required": ["id"],
+                        "additionalProperties": True,
+                        "properties": {
+                            "id": uuid
+                        }
+                    }
+                }
+            }
+        },
+        "upgrade": {
+            "type": "object",
+            "required": ["upgrade"],
+            "additionalProperties": True,
+            "properties": {
+                "upgrade": {
                     "type": "object",
-                    "required": ["id"],
+                    "required": ["datastore_version"],
                     "additionalProperties": True,
                     "properties": {
-                        "id": uuid
+                        "datastore_version": non_empty_string
                     }
                 }
             }
@@ -324,7 +381,7 @@ instance = {
         "properties": {
             "instance": {
                 "type": "object",
-                "required": ["name", "flavorRef"],
+                "required": ["name"],
                 "additionalProperties": True,
                 "properties": {
                     "name": non_empty_string,
@@ -341,18 +398,42 @@ instance = {
                             "backupRef": uuid
                         }
                     },
+                    "replica_of": uuid,
+                    "replica_count": {
+                        "type": "integer",
+                        "minimum": 1,
+                        "maximum": 3
+                    },
                     "availability_zone": non_empty_string,
                     "datastore": {
                         "type": "object",
                         "additionalProperties": True,
                         "properties": {
                             "type": non_empty_string,
-                            "version": non_empty_string
+                            "version": non_empty_string,
+                            "version_number": non_empty_string
                         }
                     },
                     "nics": nics,
                     "modules": module_list,
-                    "locality": non_empty_string
+                    "region_name": non_empty_string,
+                    "locality": non_empty_string,
+                    "access": {
+                        "type": "object",
+                        "properties": {
+                            "is_public": {"type": "boolean"},
+                            "allowed_cidrs": {
+                                "type": "array",
+                                "uniqueItems": True,
+                                "items": {
+                                    "type": "string",
+                                    "pattern": "^([0-9]{1,3}\\.){3}[0-9]{1,3}"
+                                               "(\\/([0-9]|[1-2][0-9]|3[0-2]))"
+                                               "?$"
+                                }
+                            }
+                        }
+                    }
                 }
             }
         }
@@ -376,6 +457,41 @@ instance = {
             }
         }
     },
+    "update": {
+        "name": "instance:update",
+        "type": "object",
+        "required": ["instance"],
+        "properties": {
+            "instance": {
+                "type": "object",
+                "required": [],
+                "additionalProperties": False,
+                "properties": {
+                    "name": non_empty_string,
+                    "replica_of": {},
+                    "configuration": configuration_id,
+                    "datastore_version": non_empty_string,
+                    "access": {
+                        "type": "object",
+                        "additionalProperties": False,
+                        "properties": {
+                            "is_public": {"type": "boolean"},
+                            "allowed_cidrs": {
+                                "type": "array",
+                                "uniqueItems": True,
+                                "items": {
+                                    "type": "string",
+                                    "pattern": "^([0-9]{1,3}\\.){3}[0-9]{1,3}"
+                                               "(\\/([0-9]|[1-2][0-9]|3[0-2]))"
+                                               "?$"
+                                }
+                            }
+                        }
+                    }
+                }
+            }
+        }
+    },
     "action": {
         "resize": {
             "volume": {
@@ -468,6 +584,21 @@ mgmt_instance = {
                     "type": "object"
                 }
             }
+        },
+        "rebuild": {
+            "type": "object",
+            "required": ["rebuild"],
+            "additionalProperties": True,
+            "properties": {
+                "rebuild": {
+                    "type": "object",
+                    "required": ["image_id"],
+                    "additionalProperties": False,
+                    "properties": {
+                        "image_id": uuid
+                    }
+                }
+            }
         }
     }
 }
@@ -521,19 +652,52 @@ backup = {
         "properties": {
             "backup": {
                 "type": "object",
-                "required": ["instance", "name"],
+                "required": ["name"],
                 "properties": {
                     "description": non_empty_string,
                     "instance": uuid,
                     "name": non_empty_string,
                     "parent_id": uuid,
-                    "incremental": boolean_string
+                    "incremental": boolean_string,
+                    "swift_container": non_empty_string,
+                    "restore_from": {
+                        "type": "object",
+                        "required": [
+                            "remote_location",
+                            "local_datastore_version_id",
+                            "size"
+                        ],
+                        "properties": {
+                            "remote_location": non_empty_string,
+                            "local_datastore_version_id": uuid,
+                            "size": {"type": "number"}
+                        }
+                    }
                 }
             }
         }
     }
 }
 
+backup_strategy = {
+    "create": {
+        "name": "backup_strategy:create",
+        "type": "object",
+        "required": ["backup_strategy"],
+        "properties": {
+            "backup_strategy": {
+                "type": "object",
+                "additionalProperties": False,
+                "required": ["swift_container"],
+                "properties": {
+                    "instance_id": uuid,
+                    "swift_container": non_empty_string
+                }
+            }
+        },
+    }
+}
+
 guest_log = {
     "action": {
         "name": "guest_log:action",
@@ -552,10 +716,16 @@ guest_log = {
 module_contents = {
     "type": "string",
     "minLength": 1,
-    "maxLength": 16777215,
+    "maxLength": 4294967295,
     "pattern": "^.*.+.*$"
 }
 
+module_apply_order = {
+    "type": "integer",
+    "minimum": 0,
+    "maximum": 9,
+}
+
 module = {
     "create": {
         "name": "module:create",
@@ -582,6 +752,9 @@ module = {
                     "all_tenants": boolean_string,
                     "visible": boolean_string,
                     "live_update": boolean_string,
+                    "priority_apply": boolean_string,
+                    "apply_order": module_apply_order,
+                    "full_access": boolean_string,
                 }
             }
         }
@@ -614,6 +787,9 @@ module = {
                     "all_datastore_versions": boolean_string,
                     "visible": boolean_string,
                     "live_update": boolean_string,
+                    "priority_apply": boolean_string,
+                    "apply_order": module_apply_order,
+                    "full_access": boolean_string,
                 }
             }
         }
@@ -658,7 +834,8 @@ configuration = {
                         "additionalProperties": True,
                         "properties": {
                             "type": non_empty_string,
-                            "version": non_empty_string
+                            "version": non_empty_string,
+                            "version_number": non_empty_string
                         }
                     }
                 }
@@ -785,6 +962,19 @@ package_list = {
     }
 }
 
+image_tags = {
+    "type": "array",
+    "minItems": 0,
+    "maxItems": 5,
+    "uniqueItems": True,
+    "items": {
+        "type": "string",
+        "minLength": 1,
+        "maxLength": 20,
+        "pattern": "^.*[0-9a-zA-Z]+.*$"
+    }
+}
+
 mgmt_datastore_version = {
     "create": {
         "name": "mgmt_datastore_version:create",
@@ -793,16 +983,21 @@ mgmt_datastore_version = {
         "properties": {
             "version": {
                 "type": "object",
-                "required": ["name", "datastore_name", "image", "active"],
-                "additionalProperties": True,
+                "required": ["name", "datastore_name", "datastore_manager",
+                             "active"],
+                "additionalProperties": False,
                 "properties": {
                     "name": non_empty_string,
                     "datastore_name": non_empty_string,
                     "datastore_manager": non_empty_string,
                     "packages": package_list,
                     "image": uuid,
+                    "image_tags": image_tags,
+                    "registry_ext": non_empty_string,
+                    "repl_strategy": non_empty_string,
                     "active": {"enum": [True, False]},
-                    "default": {"enum": [True, False]}
+                    "default": {"enum": [True, False]},
+                    "version": non_empty_string
                 }
             }
         }
@@ -811,13 +1006,17 @@ mgmt_datastore_version = {
         "name": "mgmt_datastore_version:edit",
         "type": "object",
         "required": [],
-        "additionalProperties": True,
+        "additionalProperties": False,
         "properties": {
             "datastore_manager": non_empty_string,
             "packages": package_list,
             "image": uuid,
+            "image_tags": image_tags,
+            "registry_ext": non_empty_string,
+            "repl_strategy": non_empty_string,
             "active": {"enum": [True, False]},
             "default": {"enum": [True, False]},
+            "name": non_empty_string
         }
     }
 }
