@@ -20,6 +20,7 @@ Projects should subclass this class if they wish to enhance the request
 context or provide additional information in their specific WSGI pipeline.
 """
 
+
 from oslo_context import context
 from oslo_log import log as logging
 
@@ -34,14 +35,15 @@ class TroveContext(context.RequestContext):
     Stores information about the security context under which the user
     accesses the system, as well as additional request information.
     """
-    def __init__(self, **kwargs):
-        self.limit = kwargs.pop('limit', None)
-        self.marker = kwargs.pop('marker', None)
-        self.service_catalog = kwargs.pop('service_catalog', None)
-        self.user_identity = kwargs.pop('user_identity', None)
-
-        # TODO(esp): not sure we need this
-        self.timeout = kwargs.pop('timeout', None)
+    def __init__(self, limit=None, marker=None, service_catalog=None,
+                 user_identity=None, instance_id=None, timeout=None,
+                 **kwargs):
+        self.limit = limit
+        self.marker = marker
+        self.service_catalog = service_catalog
+        self.user_identity = user_identity
+        self.instance_id = instance_id
+        self.timeout = timeout
         super(TroveContext, self).__init__(**kwargs)
 
         if not hasattr(local.store, 'context'):
@@ -60,24 +62,19 @@ class TroveContext(context.RequestContext):
         return parent_dict
 
     def update_store(self):
+        super(TroveContext, self).update_store()
         local.store.context = self
 
-    @classmethod
-    def _remove_incompatible_context_args(cls, values):
-        context_keys = vars(cls()).keys()
-        for dict_key in values.keys():
-            if dict_key not in context_keys:
-                LOG.debug("Argument being removed before instantiating "
-                          "TroveContext object - %s" % dict_key)
-                values.pop(dict_key, None)
-        return values
-
     @classmethod
     def from_dict(cls, values):
         n_values = values.pop('trove_notification', None)
-        values = cls._remove_incompatible_context_args(values)
-        context = cls(**values)
+        ctx = super(TroveContext, cls).from_dict(
+            values,
+            limit=values.get('limit'),
+            marker=values.get('marker'),
+            service_catalog=values.get('service_catalog'))
+
         if n_values:
-            context.notification = SerializableNotification.deserialize(
-                context, n_values)
-        return context
+            ctx.notification = SerializableNotification.deserialize(
+                ctx, n_values)
+        return ctx
