@@ -18,11 +18,11 @@ import copy
 import traceback
 
 from oslo_log import log as logging
-from oslo_utils import timeutils
 
 from trove.common import cfg
 from trove.common.exception import TroveError
 from trove.common.i18n import _
+from trove.common import timeutils
 from trove.conductor import api as conductor_api
 from trove import rpc
 
@@ -115,7 +115,7 @@ class TroveBaseTraits(object):
                 'state_description': instance.status.lower(),
                 'state': instance.status.lower(),
                 'tenant_id': instance.tenant_id,
-                'user_id': instance.context.user,
+                'user_id': instance.context.user_id,
             })
 
         self.payload.update(kwargs)
@@ -142,7 +142,7 @@ class TroveBaseTraits(object):
         publisher_id = publisher_id or CONF.host
         event_type = self.event_type_format % event_type
         event_payload = self.serialize(self.context)
-        LOG.debug('Sending event: %(event_type)s, %(payload)s' %
+        LOG.debug('Sending event: %(event_type)s, %(payload)s',
                   {'event_type': event_type, 'payload': event_payload})
 
         notifier = rpc.get_notifier(
@@ -170,11 +170,15 @@ class TroveCommonTraits(TroveBaseTraits):
             if 'instance_type' not in self.payload:
                 flavor = instance.nova_client.flavors.get(instance.flavor_id)
                 self.payload['instance_size'] = flavor.ram
-            if self.server is None:
-                self.server = instance.nova_client.servers.get(
-                    instance.server_id)
-            self.payload['availability_zone'] = getattr(
-                self.server, 'OS-EXT-AZ:availability_zone', None)
+            if self.server is None and instance.server_id:
+                try:
+                    self.server = instance.nova_client.servers.get(
+                        instance.server_id)
+                except Exception:
+                    pass
+            if self.server:
+                self.payload['availability_zone'] = getattr(
+                    self.server, 'OS-EXT-AZ:availability_zone', None)
             if CONF.get(instance.datastore_version.manager).volume_support:
                 self.payload.update({
                     'volume_size': instance.volume_size,
@@ -201,23 +205,6 @@ class TroveInstanceCreate(TroveCommonTraits):
         super(TroveInstanceCreate, self).notify('create')
 
 
-class TroveInstanceModifyVolume(TroveCommonTraits):
-
-    '''
-    Additional traits for trove.instance.create notifications that describe
-    instance action events
-
-    This class should correspond to trove_instance_modify_volume in
-    ceilometer/event_definitions.yaml
-    '''
-
-    def __init__(self, **kwargs):
-        super(TroveInstanceModifyVolume, self).__init__(**kwargs)
-
-    def notify(self):
-        super(TroveInstanceModifyVolume, self).notify('modify_volume')
-
-
 class TroveInstanceModifyFlavor(TroveCommonTraits):
 
     '''
@@ -275,7 +262,7 @@ class DBaaSQuotas(object):
         }
 
     def notify(self):
-        LOG.debug('Sending event: %(event_type)s, %(payload)s' %
+        LOG.debug('Sending event: %(event_type)s, %(payload)s',
                   {'event_type': DBaaSQuotas.event_type,
                    'payload': self.payload})
 
@@ -364,11 +351,11 @@ class DBaaSAPINotification(object):
                                 'server_type': 'api',
                                 'client_ip': request.remote_addr,
                                 'server_ip': request.host,
-                                'tenant_id': context.tenant,
+                                'tenant_id': context.project_id,
                                 })
         elif 'request_id' not in kwargs:
             raise TroveError(_("Notification %s must include 'request'"
-                             " property") % self.__class__.__name__)
+                               " property") % self.__class__.__name__)
 
         self.payload.update(kwargs)
 
@@ -385,7 +372,7 @@ class DBaaSAPINotification(object):
                                 'keys': list(required_keys - provided_keys)})
         if 'server_type' not in self.payload:
             raise TroveError(_("Notification %s must include a"
-                             " 'server_type' for correct routing")
+                               " 'server_type' for correct routing")
                              % self.__class__.__name__)
 
     def _notify(self, event_qualifier, required_traits, optional_traits,
@@ -401,7 +388,7 @@ class DBaaSAPINotification(object):
 
         qualified_event_type = (DBaaSAPINotification.event_type_format
                                 % (self.event_type(), event_qualifier))
-        LOG.debug('Sending event: %(event_type)s, %(payload)s' %
+        LOG.debug('Sending event: %(event_type)s, %(payload)s',
                   {'event_type': qualified_event_type, 'payload': payload})
 
         context = copy.copy(self.context)
@@ -436,7 +423,7 @@ class DBaaSInstanceCreate(DBaaSAPINotification):
 
     def required_start_traits(self):
         return ['name', 'flavor_id', 'datastore', 'datastore_version',
-                'image_id', 'availability_zone']
+                'image_id', 'availability_zone', 'region_name']
 
     def optional_start_traits(self):
         return ['databases', 'users', 'volume_size', 'restore_point',
@@ -447,6 +434,15 @@ class DBaaSInstanceCreate(DBaaSAPINotification):
         return ['instance_id']
 
 
+class DBaaSInstanceReboot(DBaaSAPINotification):
+
+    def event_type(self):
+        return 'instance_reboot'
+
+    def required_start_traits(self):
+        return ['instance_id']
+
+
 class DBaaSInstanceRestart(DBaaSAPINotification):
 
     def event_type(self):
@@ -549,6 +545,28 @@ class DBaaSInstanceDetachConfiguration(DBaaSAPINotification):
         return ['instance_id']
 
 
+class DBaaSClusterAttachConfiguration(DBaaSAPINotification):
+
+    @abc.abstractmethod
+    def event_type(self):
+        return 'cluster_attach_configuration'
+
+    @abc.abstractmethod
+    def required_start_traits(self):
+        return ['cluster_id', 'configuration_id']
+
+
+class DBaaSClusterDetachConfiguration(DBaaSAPINotification):
+
+    @abc.abstractmethod
+    def event_type(self):
+        return 'cluster_detach_configuration'
+
+    @abc.abstractmethod
+    def required_start_traits(self):
+        return ['cluster_id']
+
+
 class DBaaSClusterCreate(DBaaSAPINotification):
 
     @abc.abstractmethod
@@ -564,6 +582,26 @@ class DBaaSClusterCreate(DBaaSAPINotification):
         return ['cluster_id']
 
 
+class DBaaSClusterRestart(DBaaSAPINotification):
+
+    def event_type(self):
+        return 'cluster_restart'
+
+    def required_start_traits(self):
+        return ['cluster_id']
+
+
+class DBaaSClusterUpgrade(DBaaSAPINotification):
+
+    @abc.abstractmethod
+    def event_type(self):
+        return 'cluster_upgrade'
+
+    @abc.abstractmethod
+    def required_start_traits(self):
+        return ['cluster_id', 'datastore_version']
+
+
 class DBaaSClusterDelete(DBaaSAPINotification):
 
     @abc.abstractmethod
@@ -607,6 +645,10 @@ class DBaaSClusterGrow(DBaaSAPINotification):
     def required_start_traits(self):
         return ['cluster_id']
 
+    @abc.abstractmethod
+    def required_end_traits(self):
+        return ['cluster_id']
+
 
 class DBaaSClusterShrink(DBaaSAPINotification):
 
@@ -618,6 +660,10 @@ class DBaaSClusterShrink(DBaaSAPINotification):
     def required_start_traits(self):
         return ['cluster_id']
 
+    @abc.abstractmethod
+    def required_end_traits(self):
+        return ['cluster_id']
+
 
 class DBaaSBackupCreate(DBaaSAPINotification):
 
@@ -789,3 +835,14 @@ class DBaaSInstanceUpgrade(DBaaSAPINotification):
     @abc.abstractmethod
     def required_start_traits(self):
         return ['instance_id', 'datastore_version_id']
+
+
+class DBaaSInstanceMigrate(DBaaSAPINotification):
+
+    @abc.abstractmethod
+    def event_type(self):
+        return 'migrate'
+
+    @abc.abstractmethod
+    def required_start_traits(self):
+        return ['host']
