@@ -14,14 +14,14 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import jinja2
 from oslo_config import cfg as oslo_config
 from oslo_log import log as logging
 
+from semantic_version import Version
+
 from trove.common import cfg
 from trove.common import configurations
 from trove.common import exception
-from trove.common.i18n import _
 from trove.common import utils
 
 CONF = cfg.CONF
@@ -71,15 +71,20 @@ class SingleInstanceConfigTemplate(object):
             'name': self.datastore_version.datastore_name,
             'manager': self.datastore_version.manager,
             'version': self.datastore_version.name,
+            'semantic_version': self._parse_datastore_version(),
         }
         self.instance_id = instance_id
 
     def get_template(self):
         patterns = ['{name}/{version}/{template_name}',
+                    '{name}/{major}.{minor}/{template_name}',
+                    '{name}/{major}/{template_name}',
                     '{name}/{template_name}',
                     '{manager}/{template_name}']
         context = self.datastore_dict.copy()
         context['template_name'] = self.template_name
+        context['major'] = str(context['semantic_version'].major)
+        context['minor'] = str(context['semantic_version'].minor)
         names = [name.format(**context) for name in patterns]
         return ENV.select_template(names)
 
@@ -117,6 +122,24 @@ class SingleInstanceConfigTemplate(object):
         """
         return abs(hash(self.instance_id) % (2 ** 31))
 
+    def _parse_datastore_version(self):
+        """
+        Attempt to parse a version from the DatastoreVersion name.
+        Returns version 0.0.0 if unable to parse.
+
+        :return: A Version instance.
+        """
+        try:
+            return Version.coerce(self.datastore_version.version or
+                                  self.datastore_version.name)
+        except ValueError:
+            LOG.warning('Unable to parse a version number from datastore '
+                        'version name "%s" or "%s"',
+                        self.datastore_version.name,
+                        self.datastore_version.version)
+            # TODO(adrianjarvis) define default version for each datastore
+            return Version(major=0, minor=0, patch=0)
+
 
 def _validate_datastore(datastore_manager):
     try:
@@ -126,20 +149,6 @@ def _validate_datastore(datastore_manager):
             datastore_manager=datastore_manager)
 
 
-def load_heat_template(datastore_manager):
-    patterns = ["%s/heat.template" % datastore_manager,
-                "default.heat.template"]
-    _validate_datastore(datastore_manager)
-    try:
-        template_obj = ENV.select_template(patterns)
-        return template_obj
-    except jinja2.TemplateNotFound:
-        msg = _("Missing heat template for %(s_datastore_manager)s.") % (
-            {"s_datastore_manager": datastore_manager})
-        LOG.error(msg)
-        raise exception.TroveError(msg)
-
-
 class ReplicaSourceConfigTemplate(SingleInstanceConfigTemplate):
     template_name = "replica_source.config.template"
 
