@@ -48,11 +48,11 @@ class Configurations(object):
             if db_info.count() == 0:
                 LOG.debug("No configurations found for admin user")
         else:
-            db_info = DBConfiguration.find_all(tenant_id=context.tenant,
+            db_info = DBConfiguration.find_all(tenant_id=context.project_id,
                                                deleted=False)
             if db_info.count() == 0:
                 LOG.debug("No configurations found for tenant %s",
-                          context.tenant)
+                          context.project_id)
 
         limit = utils.pagination_limit(context.limit,
                                        Configurations.DEFAULT_LIMIT)
@@ -133,7 +133,7 @@ class Configuration(object):
                 return DBConfiguration.find_by(id=id, deleted=False)
             else:
                 return DBConfiguration.find_by(id=id,
-                                               tenant_id=context.tenant,
+                                               tenant_id=context.project_id,
                                                deleted=False)
         except ModelNotFoundError:
             msg = _("Configuration group with ID %s could not be found.") % id
@@ -166,6 +166,8 @@ class Configuration(object):
                 item.configuration_value = bool(int(item.configuration_value))
             elif rule.data_type == 'integer':
                 item.configuration_value = int(item.configuration_value)
+            elif rule.data_type == 'float':
+                item.configuration_value = float(item.configuration_value)
             else:
                 item.configuration_value = str(item.configuration_value)
         return config_items
@@ -189,7 +191,7 @@ class Configuration(object):
                                                 id=self.configuration_id)
         LOG.debug("config_items: %s", config_items)
         detail_list = DatastoreConfigurationParameters.load_parameters(
-            datastore_v.id, show_deleted=True)
+            datastore_v.id)
 
         for i in config_items:
             LOG.debug("config item: %s", i)
@@ -265,8 +267,6 @@ class DBDatastoreConfigurationParameters(dbmodels.DatabaseModelBase):
         'max_size',
         'min_size',
         'data_type',
-        'deleted',
-        'deleted_at',
     ]
     _table_name = "datastore_configuration_parameters"
 
@@ -287,22 +287,12 @@ class DatastoreConfigurationParameters(object):
         ds_v_id = kwargs.get('datastore_version_id')
         config_param_name = kwargs.get('name')
         try:
-            param = DatastoreConfigurationParameters.load_parameter_by_name(
+            DatastoreConfigurationParameters.load_parameter_by_name(
                 ds_v_id,
-                config_param_name,
-                show_deleted=True)
-            if param.deleted == 1:
-                param.restart_required = kwargs.get('restart_required')
-                param.data_type = kwargs.get('data_type')
-                param.max_size = kwargs.get('max_size')
-                param.min_size = kwargs.get('min_size')
-                param.deleted = 0
-                param.save()
-                return param
-            else:
-                raise exception.ConfigurationParameterAlreadyExists(
-                    parameter_name=config_param_name,
-                    datastore_version=ds_v_id)
+                config_param_name)
+            raise exception.ConfigurationParameterAlreadyExists(
+                parameter_name=config_param_name,
+                datastore_version=ds_v_id)
         except exception.NotFound:
             pass
         config_param = DBDatastoreConfigurationParameters.create(
@@ -313,54 +303,29 @@ class DatastoreConfigurationParameters(object):
     def delete(version_id, config_param_name):
         config_param = DatastoreConfigurationParameters.load_parameter_by_name(
             version_id, config_param_name)
-        config_param.deleted = True
-        config_param.deleted_at = timeutils.utcnow()
-        config_param.save()
+        config_param.delete()
 
     @classmethod
-    def load_parameters(cls, datastore_version_id, show_deleted=False):
-        try:
-            if show_deleted:
-                return DBDatastoreConfigurationParameters.find_all(
-                    datastore_version_id=datastore_version_id
-                )
-            else:
-                return DBDatastoreConfigurationParameters.find_all(
-                    datastore_version_id=datastore_version_id,
-                    deleted=False
-                )
-        except exception.NotFound:
-            raise exception.NotFound(uuid=datastore_version_id)
+    def load_parameters(cls, datastore_version_id):
+        return DBDatastoreConfigurationParameters.find_all(
+            datastore_version_id=datastore_version_id)
 
     @classmethod
-    def load_parameter(cls, config_id, show_deleted=False):
+    def load_parameter(cls, config_id):
         try:
-            if show_deleted:
-                return DBDatastoreConfigurationParameters.find_by(
-                    id=config_id
-                )
-            else:
-                return DBDatastoreConfigurationParameters.find_by(
-                    id=config_id, deleted=False
-                )
+            return DBDatastoreConfigurationParameters.find_by(
+                id=config_id, deleted=False
+            )
         except exception.NotFound:
             raise exception.NotFound(uuid=config_id)
 
     @classmethod
-    def load_parameter_by_name(cls, datastore_version_id, config_param_name,
-                               show_deleted=False):
+    def load_parameter_by_name(cls, datastore_version_id, config_param_name):
         try:
-            if show_deleted:
-                return DBDatastoreConfigurationParameters.find_by(
-                    datastore_version_id=datastore_version_id,
-                    name=config_param_name
-                )
-            else:
-                return DBDatastoreConfigurationParameters.find_by(
-                    datastore_version_id=datastore_version_id,
-                    name=config_param_name,
-                    deleted=False
-                )
+            return DBDatastoreConfigurationParameters.find_by(
+                datastore_version_id=datastore_version_id,
+                name=config_param_name
+            )
         except exception.NotFound:
             raise exception.NotFound(uuid=config_param_name)
 
@@ -371,12 +336,12 @@ def create_or_update_datastore_configuration_parameter(name,
                                                        data_type,
                                                        max_size,
                                                        min_size):
-    get_db_api().configure_db(CONF)
+    get_db_api().configure_db()
     datastore_version = dstore_models.DatastoreVersion.load_by_uuid(
         datastore_version_id)
     try:
         config = DatastoreConfigurationParameters.load_parameter_by_name(
-            datastore_version_id, name, show_deleted=True)
+            datastore_version_id, name)
         config.restart_required = restart_required
         config.max_size = max_size
         config.min_size = min_size
@@ -391,17 +356,16 @@ def create_or_update_datastore_configuration_parameter(name,
             data_type=data_type,
             max_size=max_size,
             min_size=min_size,
-            deleted=False,
         )
         get_db_api().save(config)
 
 
-def load_datastore_configuration_parameters(datastore,
-                                            datastore_version,
-                                            config_file):
-    get_db_api().configure_db(CONF)
+def load_datastore_configuration_parameters(datastore, datastore_version,
+                                            config_file, version_number=None):
+    get_db_api().configure_db()
     (ds, ds_v) = dstore_models.get_datastore_version(
-        type=datastore, version=datastore_version, return_inactive=True)
+        type=datastore, version=datastore_version, return_inactive=True,
+        version_number=version_number)
     with open(config_file) as f:
         config = json.load(f)
         for param in config['configuration-parameters']:
@@ -415,10 +379,21 @@ def load_datastore_configuration_parameters(datastore,
             )
 
 
+def remove_datastore_configuration_parameters(datastore, datastore_version,
+                                              version_number=None):
+    get_db_api().configure_db()
+    (ds, ds_version) = dstore_models.get_datastore_version(
+        type=datastore, version=datastore_version, return_inactive=True,
+        version_number=version_number)
+    db_params = DatastoreConfigurationParameters.load_parameters(ds_version.id)
+    for db_param in db_params:
+        db_param.delete()
+
+
 def persisted_models():
     return {
         'configurations': DBConfiguration,
         'configuration_parameters': DBConfigurationParameter,
         'datastore_configuration_parameters':
-        DBDatastoreConfigurationParameters,
+            DBDatastoreConfigurationParameters,
     }
