@@ -13,11 +13,9 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from datetime import datetime
-
 from oslo_log import log as logging
-import six
 
+from trove.cluster import models as cluster_models
 import trove.common.apischema as apischema
 from trove.common import cfg
 from trove.common import exception
@@ -25,6 +23,8 @@ from trove.common.i18n import _
 from trove.common import notification
 from trove.common.notification import StartNotification, EndNotification
 from trove.common import pagination
+from trove.common import policy
+from trove.common import timeutils
 from trove.common import wsgi
 from trove.configuration import models
 from trove.configuration.models import DBConfigurationParameter
@@ -41,25 +41,38 @@ class ConfigurationsController(wsgi.Controller):
 
     schemas = apischema.configuration
 
+    @classmethod
+    def authorize_config_action(cls, context, config_rule_name, config):
+        policy.authorize_on_target(
+            context, 'configuration:%s' % config_rule_name,
+            {'tenant': config.tenant_id})
+
     def index(self, req, tenant_id):
         context = req.environ[wsgi.CONTEXT_KEY]
         configs, marker = models.Configurations.load(context)
+        policy.authorize_on_tenant(context, 'configuration:index')
         view = views.ConfigurationsView(configs)
         paged = pagination.SimplePaginatedDataView(req.url, 'configurations',
                                                    view, marker)
         return wsgi.Result(paged.data(), 200)
 
     def show(self, req, tenant_id, id):
-        LOG.debug("Showing configuration group %(id)s on tenant %(tenant)s"
-                  % {"tenant": tenant_id, "id": id})
+        LOG.debug("Showing configuration group %(id)s on tenant %(tenant)s",
+                  {"tenant": tenant_id, "id": id})
         context = req.environ[wsgi.CONTEXT_KEY]
         configuration = models.Configuration.load(context, id)
+        self.authorize_config_action(context, 'show', configuration)
         configuration_items = models.Configuration.load_items(context, id)
 
+        find_instance = {
+            'configuration_id': configuration.id,
+            'deleted': False
+        }
+        if not context.is_admin:
+            find_instance['tenant_id'] = context.project_id
+
         configuration.instance_count = instances_models.DBInstance.find_all(
-            tenant_id=context.tenant,
-            configuration_id=configuration.id,
-            deleted=False).count()
+            **find_instance).count()
 
         return wsgi.Result(views.DetailedConfigurationView(
                            configuration,
@@ -68,10 +81,16 @@ class ConfigurationsController(wsgi.Controller):
     def instances(self, req, tenant_id, id):
         context = req.environ[wsgi.CONTEXT_KEY]
         configuration = models.Configuration.load(context, id)
-        instances = instances_models.DBInstance.find_all(
-            tenant_id=context.tenant,
-            configuration_id=configuration.id,
-            deleted=False)
+        self.authorize_config_action(context, 'instances', configuration)
+
+        kwargs = {
+            'configuration_id': configuration.id,
+            'deleted': False
+        }
+        if not context.is_admin:
+            kwargs['tenant_id'] = context.project_id
+        instances = instances_models.DBInstance.find_all(**kwargs)
+
         limit = int(context.limit or CONF.instances_page_size)
         if limit > CONF.instances_page_size:
             limit = CONF.instances_page_size
@@ -85,19 +104,20 @@ class ConfigurationsController(wsgi.Controller):
         return wsgi.Result(paged.data(), 200)
 
     def create(self, req, body, tenant_id):
-        LOG.debug("req : '%s'\n\n" % req)
-        LOG.debug("body : '%s'\n\n" % req)
+        LOG.debug("req : '%s'\n\n", req)
+        LOG.debug("body : '%s'\n\n", req)
 
         context = req.environ[wsgi.CONTEXT_KEY]
+        policy.authorize_on_tenant(context, 'configuration:create')
         context.notification = notification.DBaaSConfigurationCreate(
             context, request=req)
         name = body['configuration']['name']
         description = body['configuration'].get('description')
         values = body['configuration']['values']
 
-        msg = _("Creating configuration group on tenant "
-                "%(tenant_id)s with name: %(cfg_name)s")
-        LOG.info(msg % {"tenant_id": tenant_id, "cfg_name": name})
+        msg = ("Creating configuration group on tenant "
+               "%(tenant_id)s with name: %(cfg_name)s")
+        LOG.info(msg, {"tenant_id": tenant_id, "cfg_name": name})
 
         datastore_args = body['configuration'].get('datastore', {})
         datastore, datastore_version = (
@@ -132,17 +152,18 @@ class ConfigurationsController(wsgi.Controller):
         return wsgi.Result(view_data.data(), 200)
 
     def delete(self, req, tenant_id, id):
-        msg = _("Deleting configuration group %(cfg_id)s on tenant: "
-                "%(tenant_id)s")
-        LOG.info(msg % {"tenant_id": tenant_id, "cfg_id": id})
+        msg = ("Deleting configuration group %(cfg_id)s on tenant: "
+               "%(tenant_id)s")
+        LOG.info(msg, {"tenant_id": tenant_id, "cfg_id": id})
 
         context = req.environ[wsgi.CONTEXT_KEY]
+        group = models.Configuration.load(context, id)
+        self.authorize_config_action(context, 'delete', group)
         context.notification = notification.DBaaSConfigurationDelete(
             context, request=req)
         with StartNotification(context, configuration_id=id):
-            group = models.Configuration.load(context, id)
             instances = instances_models.DBInstance.find_all(
-                tenant_id=context.tenant,
+                tenant_id=context.project_id,
                 configuration_id=id,
                 deleted=False).all()
             if instances:
@@ -151,12 +172,21 @@ class ConfigurationsController(wsgi.Controller):
         return wsgi.Result(None, 202)
 
     def update(self, req, body, tenant_id, id):
-        msg = _("Updating configuration group %(cfg_id)s for tenant "
-                "id %(tenant_id)s")
-        LOG.info(msg % {"tenant_id": tenant_id, "cfg_id": id})
+        msg = ("Updating configuration group %(cfg_id)s for tenant "
+               "id %(tenant_id)s")
+        LOG.info(msg, {"tenant_id": tenant_id, "cfg_id": id})
 
         context = req.environ[wsgi.CONTEXT_KEY]
         group = models.Configuration.load(context, id)
+        # Note that changing the configuration group will also
+        # indirectly affect all the instances which attach it.
+        #
+        # The Trove instance itself won't be changed (the same group is still
+        # attached) but the configuration values will.
+        #
+        # The operator needs to keep this in mind when defining the related
+        # policies.
+        self.authorize_config_action(context, 'update', group)
 
         # if name/description are provided in the request body, update the
         # model with these values as well.
@@ -172,42 +202,58 @@ class ConfigurationsController(wsgi.Controller):
                                name=group.name, description=group.description):
             items = self._configuration_items_list(group,
                                                    body['configuration'])
-            deleted_at = datetime.utcnow()
+            deleted_at = timeutils.utcnow()
             models.Configuration.remove_all_items(context, group.id,
                                                   deleted_at)
             models.Configuration.save(group, items)
             self._refresh_on_all_instances(context, id)
+            self._refresh_on_all_clusters(context, id)
+
         return wsgi.Result(None, 202)
 
     def edit(self, req, body, tenant_id, id):
         context = req.environ[wsgi.CONTEXT_KEY]
+        group = models.Configuration.load(context, id)
+        self.authorize_config_action(context, 'edit', group)
         context.notification = notification.DBaaSConfigurationEdit(
             context, request=req)
         with StartNotification(context, configuration_id=id):
-            group = models.Configuration.load(context, id)
             items = self._configuration_items_list(group,
                                                    body['configuration'])
             models.Configuration.save(group, items)
             self._refresh_on_all_instances(context, id)
+            self._refresh_on_all_clusters(context, id)
 
     def _refresh_on_all_instances(self, context, configuration_id):
-        """Refresh a configuration group on all its instances.
+        """Refresh a configuration group on all single instances.
         """
-        dbinstances = instances_models.DBInstance.find_all(
-            tenant_id=context.tenant,
+        single_instances = instances_models.DBInstance.find_all(
+            tenant_id=context.project_id,
+            configuration_id=configuration_id,
+            cluster_id=None,
+            deleted=False).all()
+
+        config = models.Configuration(context, configuration_id)
+        for dbinstance in single_instances:
+            LOG.info("Re-applying configuration %s to instance: %s",
+                     configuration_id, dbinstance.id)
+            instance = instances_models.Instance.load(context, dbinstance.id)
+            instance.update_configuration(config)
+
+    def _refresh_on_all_clusters(self, context, configuration_id):
+        """Refresh a configuration group on all clusters.
+        """
+        LOG.debug("Re-applying configuration group '%s' to all clusters.",
+                  configuration_id)
+        clusters = cluster_models.DBCluster.find_all(
+            tenant_id=context.project_id,
             configuration_id=configuration_id,
             deleted=False).all()
 
-        LOG.debug(
-            "All instances with configuration group '%s' on tenant '%s': %s"
-            % (configuration_id, context.tenant, dbinstances))
-
-        config = models.Configuration(context, configuration_id)
-        for dbinstance in dbinstances:
-            LOG.debug("Applying configuration group '%s' to instance: %s"
-                      % (configuration_id, dbinstance.id))
-            instance = instances_models.Instance.load(context, dbinstance.id)
-            instance.update_overrides(config)
+        for dbcluster in clusters:
+            LOG.debug("Re-applying configuration to cluster: %s", dbcluster.id)
+            cluster = cluster_models.Cluster.load(context, dbcluster.id)
+            cluster.configuration_attach(configuration_id)
 
     def _configuration_items_list(self, group, configuration):
         ds_version_id = group.datastore_version_id
@@ -230,7 +276,7 @@ class ConfigurationsController(wsgi.Controller):
 
     @staticmethod
     def _validate_configuration(values, datastore_version, config_rules):
-        LOG.info(_("Validating configuration values"))
+        LOG.info("Validating configuration values")
 
         # create rules dictionary based on parameter name
         rules_lookup = {}
@@ -270,7 +316,7 @@ class ConfigurationsController(wsgi.Controller):
                 raise exception.UnprocessableEntity(message=msg)
 
             # integer min/max checking
-            if isinstance(v, six.integer_types) and not isinstance(v, bool):
+            if isinstance(v, int) and not isinstance(v, bool):
                 if rule.min_size is not None:
                     try:
                         min_value = int(rule.min_size)
@@ -308,9 +354,9 @@ class ConfigurationsController(wsgi.Controller):
         if value_type == "boolean":
             return bool
         elif value_type == "string":
-            return six.string_types
+            return str
         elif value_type == "integer":
-            return six.integer_types
+            return int
         elif value_type == "float":
             return float
         else:
@@ -329,7 +375,18 @@ class ConfigurationsController(wsgi.Controller):
 
 class ParametersController(wsgi.Controller):
 
+    @classmethod
+    def authorize_request(cls, req, rule_name):
+        """Parameters (configuration templates) bind to a datastore.
+        Datastores are not owned by any particular tenant so we only check
+        the current tenant is allowed to perform the action.
+        """
+        context = req.environ[wsgi.CONTEXT_KEY]
+        policy.authorize_on_tenant(context, 'configuration-parameter:%s'
+                                   % rule_name)
+
     def index(self, req, tenant_id, datastore, id):
+        self.authorize_request(req, 'index')
         ds, ds_version = ds_models.get_datastore_version(
             type=datastore, version=id)
         rules = models.DatastoreConfigurationParameters.load_parameters(
@@ -338,6 +395,7 @@ class ParametersController(wsgi.Controller):
                            200)
 
     def show(self, req, tenant_id, datastore, id, name):
+        self.authorize_request(req, 'show')
         ds, ds_version = ds_models.get_datastore_version(
             type=datastore, version=id)
         rule = models.DatastoreConfigurationParameters.load_parameter_by_name(
@@ -345,6 +403,7 @@ class ParametersController(wsgi.Controller):
         return wsgi.Result(views.ConfigurationParameterView(rule).data(), 200)
 
     def index_by_version(self, req, tenant_id, version):
+        self.authorize_request(req, 'index_by_version')
         ds_version = ds_models.DatastoreVersion.load_by_uuid(version)
         rules = models.DatastoreConfigurationParameters.load_parameters(
             ds_version.id)
@@ -352,6 +411,7 @@ class ParametersController(wsgi.Controller):
                            200)
 
     def show_by_version(self, req, tenant_id, version, name):
+        self.authorize_request(req, 'show_by_version')
         ds_models.DatastoreVersion.load_by_uuid(version)
         rule = models.DatastoreConfigurationParameters.load_parameter_by_name(
             version, name)
