@@ -26,15 +26,15 @@ from trove.common import cfg
 from trove.common import exception
 from trove.common.i18n import _
 from trove.common.notification import EndNotification
-from trove.guestagent import dbaas
-from trove.guestagent import guest_log
-from trove.guestagent import volume
 from trove.guestagent.common import guestagent_utils
 from trove.guestagent.common import operating_system
 from trove.guestagent.common.operating_system import FileMode
+from trove.guestagent import dbaas
+from trove.guestagent import guest_log
 from trove.guestagent.module import driver_manager
 from trove.guestagent.module import module_manager
 from trove.guestagent.strategies import replication as repl_strategy
+from trove.guestagent import volume
 from trove.instance import service_status
 
 LOG = logging.getLogger(__name__)
@@ -511,7 +511,7 @@ class Manager(periodic_task.PeriodicTasks):
                         exposed)
 
                     if (gl_def[self.GUEST_LOG_TYPE_LABEL] ==
-                        guest_log.LogType.USER):
+                            guest_log.LogType.USER):
                         guestlog.enabled = self.is_log_enabled(log_name)
                         guestlog.status = (guest_log.LogStatus.Enabled
                                            if guestlog.enabled
@@ -792,7 +792,13 @@ class Manager(periodic_task.PeriodicTasks):
                                        'encrypted backup.')
 
         try:
-            self.app.restore_backup(context, backup_info, restore_location)
+            storage_driver = backup_info.get(
+                'storage_driver', CONF.storage_strategy)
+            if storage_driver in ["cinder"]:
+                self.app.restore_snapshot(
+                    context, backup_info, restore_location)
+            else:
+                self.app.restore_backup(context, backup_info, restore_location)
         except Exception:
             LOG.error("Failed to restore from backup %s.", backup_info['id'])
             self.status.set_status(service_status.ServiceStatuses.FAILED)
@@ -941,3 +947,32 @@ class Manager(periodic_task.PeriodicTasks):
     def wait_for_txn(self, context, txn):
         raise exception.DatastoreOperationNotSupported(
             operation='wait_for_txn', datastore=self.manager)
+
+    def pre_create_backup(self, context, **kwargs):
+        """This is called before do create backup without drivers
+        that do in guest
+        """
+        LOG.info('No pre_create_backup work has been defined.')
+        try:
+            mount_point = CONF.get(CONF.datastore_manager).mount_point
+            # Sync Disk
+            operating_system.sync(mount_point)
+            # Freeze FS
+            operating_system.fsfreeze(mount_point)
+        except Exception as e:
+            LOG.error("Run pre_create_backup failed, error: %s" % str(e))
+
+        return {}
+
+    def post_create_backup(self, context, **kwargs):
+        """This is called after do create backup without drivers
+        that do in guest
+        """
+        LOG.info('No post_create_backup work has been defined.')
+        try:
+            mount_point = CONF.get(CONF.datastore_manager).mount_point
+            operating_system.fsunfreeze(mount_point)
+        except Exception as e:
+            LOG.error("Run post_create_backup failed, error: %s" % str(e))
+
+        return {}
