@@ -15,6 +15,7 @@
 #
 
 from oslo_log import log as logging
+from oslo_utils.excutils import save_and_reraise_exception
 
 from trove.common import cfg
 from trove.common import constants
@@ -30,6 +31,21 @@ LOG = logging.getLogger(__name__)
 
 
 class MariaDBApp(mysql_service.BaseMySqlApp):
+
+    HEALTHCHECK = {
+        "test": ["CMD", "healthcheck.sh", "--defaults-file",
+                 "/var/lib/mysql/data/.my-healthcheck.cnf",
+                 "--connect", "--innodb_initialized"],
+        "start_period": 10 * 1000000000,  # 10 seconds in nanoseconds
+        "interval": 10 * 1000000000,
+        "timeout": 5 * 1000000000,
+        "retries": 3
+    }
+    # # to regenerate the .my-healthcheck.cnf after restoring
+    _extra_envs = {"MARIADB_AUTO_UPGRADE": 1}
+    # Set to True for io_uring feature
+    _previledged = True
+
     def __init__(self, status, docker_client):
         super(MariaDBApp, self).__init__(status, docker_client)
 
@@ -85,9 +101,13 @@ class MariaDBApp(mysql_service.BaseMySqlApp):
         with mysql_util.SqlClient(self.get_engine()) as client:
             client.execute(cmd)
 
+    def wipe_ib_logfiles(self):
+        # mariadb_backup doesn't need to delete this file
+        pass
+
     def reset_data_for_restore_snapshot(self, data_dir):
         """This function try remove slave status in database"""
-        command = "mysqld --skip-slave-start=ON --datadir=%s" % data_dir
+        command = "--skip-slave-start=ON --datadir=%s" % data_dir
 
         extra_volumes = {
             "/etc/mysql": {"bind": "/etc/mysql", "mode": "rw"},
@@ -100,8 +120,9 @@ class MariaDBApp(mysql_service.BaseMySqlApp):
             self.start_db(ds_version=CONF.datastore_version, command=command,
                           extra_volumes=extra_volumes)
             self.stop_slave(for_failover=False)
-        except Exception as e:
-            LOG.error("Failed to start db to restore snapshot: %s", str(e))
+        except Exception as err:
+            with save_and_reraise_exception():
+                LOG.error("Failed to remove slave status: %s", str(err))
         finally:
             try:
                 LOG.debug(
