@@ -17,7 +17,6 @@ import os
 import re
 
 from oslo_log import log as logging
-from oslo_utils import encodeutils
 import sqlalchemy
 from sqlalchemy import event
 from sqlalchemy import exc
@@ -62,41 +61,6 @@ BACKUP_LOG = re.compile(r'.*Backup successfully, checksum: (?P<checksum>.*), '
                         r'location: (?P<location>.*)')
 
 
-class BaseMySqlAppStatus(service.BaseDbStatus):
-
-    def __init__(self, docker_client):
-        super(BaseMySqlAppStatus, self).__init__(docker_client)
-
-    def get_actual_db_status(self):
-        """Check database service status."""
-        status = docker_util.get_container_status(self.docker_client)
-        if status == "running":
-            root_pass = service.BaseDbApp.get_auth_password(file="root.cnf")
-            cmd = 'mysql -uroot -p%s -e "select 1;"' % root_pass
-            try:
-                docker_util.run_command(self.docker_client, cmd)
-                return service_status.ServiceStatuses.HEALTHY
-            except Exception as exc:
-                LOG.warning('Failed to run docker command, error: %s',
-                            str(exc))
-                container_log = docker_util.get_container_logs(
-                    self.docker_client, tail='all')
-                LOG.debug('container log: \n%s', '\n'.join(container_log))
-                return service_status.ServiceStatuses.RUNNING
-        elif status == "not running":
-            return service_status.ServiceStatuses.SHUTDOWN
-        elif status == "restarting":
-            return service_status.ServiceStatuses.SHUTDOWN
-        elif status == "paused":
-            return service_status.ServiceStatuses.PAUSED
-        elif status == "exited":
-            return service_status.ServiceStatuses.SHUTDOWN
-        elif status == "dead":
-            return service_status.ServiceStatuses.CRASHED
-        else:
-            return service_status.ServiceStatuses.UNKNOWN
-
-
 class BaseMySqlAdmin(object, metaclass=abc.ABCMeta):
     """Handles administrative tasks on the MySQL database."""
 
@@ -245,11 +209,9 @@ class BaseMySqlAdmin(object, metaclass=abc.ABCMeta):
             user.check_reserved()
         except ValueError as ve:
             LOG.exception("Error Getting user information")
-            err_msg = encodeutils.exception_to_unicode(ve)
-            raise exception.BadRequest(_("Username %(user)s is not valid"
-                                         ": %(reason)s") %
-                                       {'user': username, 'reason': err_msg}
-                                       )
+            raise exception.BadRequest(
+                _("Username %(user)s is not valid: %(reason)s") %
+                {'user': username, 'reason': ve})
         with mysql_util.SqlClient(
                 self.mysql_app.get_engine(), use_flush=True) as client:
             q = sql_query.Query()
@@ -438,6 +400,8 @@ class BaseMySqlAdmin(object, metaclass=abc.ABCMeta):
 
 class BaseMySqlApp(service.BaseDbApp):
     _configuration_manager = None
+    _extra_envs = {}
+    _previledged = False
 
     @property
     def configuration_manager(self):
@@ -623,6 +587,12 @@ class BaseMySqlApp(service.BaseDbApp):
         else:
             network_mode = constants.DOCKER_BRIDGE_MODE
 
+        environment = {
+            "MYSQL_ROOT_PASSWORD": root_pass,
+            "MYSQL_INITDB_SKIP_TZINFO": 1}
+        if self._extra_envs:
+            environment.update(self._extra_envs)
+
         try:
             docker_util.start_container(
                 self.docker_client,
@@ -631,11 +601,10 @@ class BaseMySqlApp(service.BaseDbApp):
                 network_mode=network_mode,
                 ports=ports,
                 user=user,
-                environment={
-                    "MYSQL_ROOT_PASSWORD": root_pass,
-                    "MYSQL_INITDB_SKIP_TZINFO": 1,
-                },
-                command=command
+                environment=environment,
+                healthcheck=self.HEALTHCHECK,
+                command=command,
+                privileged=self._previledged
             )
 
             # Save root password
@@ -709,7 +678,7 @@ class BaseMySqlApp(service.BaseDbApp):
         volumes = {'/var/lib/mysql': {'bind': '/var/lib/mysql', 'mode': 'rw'}}
 
         command = (
-            f'/usr/bin/python3 main.py --nobackup '
+            f'python3 main.py --nobackup '
             f'--storage-driver={storage_driver} --driver={backup_driver} '
             f'--os-token={user_token} --os-auth-url={auth_url} '
             f'--os-tenant-id={user_tenant} --os-region-name={region_name} '
@@ -814,14 +783,16 @@ class BaseMySqlApp(service.BaseDbApp):
 
         replication_user = None
         with mysql_util.SqlClient(self.get_engine()) as client:
-            result = client.execute(text('SHOW SLAVE STATUS'))
-            replication_user = result.first()._mapping['Master_User']
-            client.execute(text('STOP SLAVE'))
-            client.execute(text('RESET SLAVE ALL'))
-            self.wait_for_slave_status('OFF', client, 180)
-            if not for_failover:
-                client.execute(text('DROP USER IF EXISTS ' + replication_user))
-
+            result = client.execute(
+                text('SHOW SLAVE STATUS')).mappings().first()
+            if result:
+                replication_user = result['Master_User']
+                client.execute(text('STOP SLAVE'))
+                client.execute(text('RESET SLAVE ALL'))
+                self.wait_for_slave_status('OFF', client, 180)
+                if not for_failover:
+                    client.execute(
+                        text('DROP USER IF EXISTS ' + replication_user))
         return {
             'replication_user': replication_user
         }
