@@ -44,40 +44,17 @@ HBA_CONFIG_FILE = '/etc/postgresql/pg_hba.conf'
 WAL_ARCHIVE_DIR = '/var/lib/postgresql/data/wal_archive'
 
 
-class PgSqlAppStatus(service.BaseDbStatus):
-    def __init__(self, docker_client):
-        super(PgSqlAppStatus, self).__init__(docker_client)
-
-    def get_actual_db_status(self):
-        """Check database service status."""
-        status = docker_util.get_container_status(self.docker_client)
-        if status == "running":
-            cmd = "psql -U postgres -c 'select 1;'"
-            try:
-                docker_util.run_command(self.docker_client, cmd)
-                return service_status.ServiceStatuses.HEALTHY
-            except Exception as exc:
-                LOG.warning('Failed to run docker command, error: %s',
-                            str(exc))
-                container_log = docker_util.get_container_logs(
-                    self.docker_client, tail='all')
-                LOG.debug('container log: \n%s', '\n'.join(container_log))
-                return service_status.ServiceStatuses.RUNNING
-        elif status == "not running":
-            return service_status.ServiceStatuses.SHUTDOWN
-        elif status == "paused":
-            return service_status.ServiceStatuses.PAUSED
-        elif status == "exited":
-            return service_status.ServiceStatuses.SHUTDOWN
-        elif status == "dead":
-            return service_status.ServiceStatuses.CRASHED
-        else:
-            return service_status.ServiceStatuses.UNKNOWN
-
-
 class PgSqlApp(service.BaseDbApp):
     _configuration_manager = None
 
+    HEALTHCHECK = {
+        "test": ["CMD", "pg_isready", "-U", "postgres"],
+        "start_period": 10 * 1000000000,  # 10 seconds in nanoseconds
+        "interval": 10 * 1000000000,
+        "timeout": 5 * 1000000000,
+        "retries": 3
+    }
+
     @property
     def configuration_manager(self):
         if self._configuration_manager:
@@ -221,6 +198,7 @@ class PgSqlApp(service.BaseDbApp):
                     "POSTGRES_PASSWORD": postgres_pass,
                     "PGDATA": self.datadir,
                 },
+                healthcheck=self.HEALTHCHECK,
                 command=command
             )
 
@@ -281,7 +259,7 @@ class PgSqlApp(service.BaseDbApp):
                    f"--os-region-name={CONF.service_credentials.region_name}")
 
         command = (
-            f'/usr/bin/python3 main.py --nobackup '
+            f'python3 main.py --nobackup '
             f'--storage-driver={storage_driver} --driver={backup_driver} '
             f'{os_cred} '
             f'--restore-from={backup_info["location"]} '
