@@ -119,7 +119,25 @@ class BaseDbStatus(object):
         self.set_status(real_status, force=force)
 
     def get_actual_db_status(self):
-        raise NotImplementedError()
+        """Check database service status."""
+        health = docker_util.get_container_health(self.docker_client)
+        LOG.debug('container health status: %s', health)
+        if health == "healthy":
+            return service_status.ServiceStatuses.HEALTHY
+        elif health == "starting":
+            return service_status.ServiceStatuses.RUNNING
+        # when the container is not found, it returns not running
+        elif health == "not running":
+            return service_status.ServiceStatuses.SHUTDOWN
+        elif health == "unhealthy":
+            # In case the container was stopped
+            status = docker_util.get_container_status(self.docker_client)
+            if status == "exited":
+                return service_status.ServiceStatuses.SHUTDOWN
+            else:
+                return service_status.ServiceStatuses.CRASHED
+
+        return service_status.ServiceStatuses.UNKNOWN
 
     @property
     def is_installed(self):
@@ -342,6 +360,7 @@ class BaseDbStatus(object):
 
 class BaseDbApp(object):
     CFG_CODEC = stream_codecs.IniCodec()
+    HEALTHCHECK = None
 
     def __init__(self, status, docker_client):
         self.status = status
@@ -436,6 +455,14 @@ class BaseDbApp(object):
 
     def get_backup_image(self):
         image = cfg.get_configuration_property('backup_docker_image')
+        if not image:
+            LOG.error(
+                "Image to perform backup was not found in configuration. "
+                "Please, define `backup_docker_image` option in "
+                "corresponding datastore section for trove-guestagent "
+                "configuration file."
+            )
+            raise exception.TroveError("Backup image was not defined")
         if not self._image_has_tag(image):
             ds_version = CONF.datastore_version
             image = (f'{image}:latest' if not ds_version else
@@ -461,7 +488,6 @@ class BaseDbApp(object):
 
         name = 'db_backup'
         backup_id = backup_info["id"]
-        image = self.get_backup_image()
         os_cred = (f"--os-token={context.auth_token} "
                    f"--os-auth-url={CONF.service_credentials.auth_url} "
                    f"--os-tenant-id={context.project_id} "
@@ -484,7 +510,7 @@ class BaseDbApp(object):
                         f'--swift-container={swift_container}')
 
         command = (
-            f'/usr/bin/python3 main.py --backup --backup-id={backup_id} '
+            f'python3 main.py --backup --backup-id={backup_id} '
             f'--storage-driver={storage_driver} --driver={backup_driver} '
             f'{os_cred} '
             f'{db_userinfo} '
@@ -510,6 +536,7 @@ class BaseDbApp(object):
 
         # Start to run backup inside a separate docker container
         try:
+            image = self.get_backup_image()
             LOG.info(f'Starting to create backup {backup_id}, '
                      f'command: {command}')
             output, ret = docker_util.run_container(
