@@ -15,7 +15,6 @@
 #
 
 from oslo_log import log as logging
-from oslo_utils import encodeutils
 import stevedore
 
 from trove.common import base_exception as exception
@@ -71,8 +70,7 @@ class ModuleDriverManager(object):
                 LOG.info("Driver '%s' not supported, skipping",
                          driver.get_type())
         except AttributeError as ex:
-            LOG.exception("Exception loading module driver: %s",
-                          encodeutils.exception_to_unicode(ex))
+            LOG.exception("Exception loading module driver: %s", ex)
 
         return supported
 
