@@ -15,11 +15,11 @@
 #
 
 import datetime
+import operator
 import os
 
 from oslo_log import log as logging
 
-from trove.common import cfg
 from trove.common import exception
 from trove.common.i18n import _
 from trove.common import stream_codecs
@@ -28,7 +28,6 @@ from trove.guestagent.common import operating_system
 
 
 LOG = logging.getLogger(__name__)
-CONF = cfg.CONF
 
 
 class ModuleManager(object):
@@ -43,12 +42,12 @@ class ModuleManager(object):
 
     @classmethod
     def get_current_timestamp(cls):
-        return datetime.datetime.now().strftime("%Y-%m-%d %H:%M:%S")
+        return datetime.datetime.now().strftime("%Y-%m-%d %H:%M:%S.%f")[0:22]
 
     @classmethod
     def apply_module(cls, driver, module_type, name, tenant,
                      datastore, ds_version, contents, module_id, md5,
-                     auto_apply, visible):
+                     auto_apply, visible, admin_module):
         tenant = tenant or cls.MODULE_APPLY_TO_ALL
         datastore = datastore or cls.MODULE_APPLY_TO_ALL
         ds_version = ds_version or cls.MODULE_APPLY_TO_ALL
@@ -59,17 +58,17 @@ class ModuleManager(object):
         now = cls.get_current_timestamp()
         default_result = cls.build_default_result(
             module_type, name, tenant, datastore,
-            ds_version, module_id, md5, auto_apply, visible, now)
+            ds_version, module_id, md5,
+            auto_apply, visible, now, admin_module)
         result = cls.read_module_result(module_dir, default_result)
-        admin_module = cls.is_admin_module(tenant, auto_apply, visible)
         try:
             driver.configure(name, datastore, ds_version, data_file)
             applied, message = driver.apply(
                 name, datastore, ds_version, data_file, admin_module)
         except Exception as ex:
-            LOG.exception(_("Could not apply module '%s'") % name)
+            LOG.exception("Could not apply module '%s'", name)
             applied = False
-            message = ex.message
+            message = str(ex)
         finally:
             status = 'OK' if applied else 'ERROR'
             result['removed'] = None
@@ -85,7 +84,7 @@ class ModuleManager(object):
             result['tenant'] = tenant
             result['auto_apply'] = auto_apply
             result['visible'] = visible
-            result['admin_only'] = admin_module
+            result['is_admin'] = admin_module
             cls.write_module_result(module_dir, result)
         return result
 
@@ -95,7 +94,7 @@ class ModuleManager(object):
         module_dir = guestagent_utils.build_file_path(
             cls.MODULE_BASE_DIR, sub_dir)
         if not operating_system.exists(module_dir, is_directory=True):
-            operating_system.create_directory(module_dir, force=True)
+            operating_system.ensure_directory(module_dir, force=True)
         return module_dir
 
     @classmethod
@@ -115,8 +114,7 @@ class ModuleManager(object):
     @classmethod
     def build_default_result(cls, module_type, name, tenant,
                              datastore, ds_version, module_id, md5,
-                             auto_apply, visible, now):
-        admin_module = cls.is_admin_module(tenant, auto_apply, visible)
+                             auto_apply, visible, now, admin_module):
         result = {
             'type': module_type,
             'name': name,
@@ -132,7 +130,7 @@ class ModuleManager(object):
             'removed': None,
             'auto_apply': auto_apply,
             'visible': visible,
-            'admin_only': admin_module,
+            'is_admin': admin_module,
             'contents': None,
         }
         return result
@@ -151,7 +149,7 @@ class ModuleManager(object):
                 result_file, codec=stream_codecs.JsonCodec())
         except Exception:
             if not result:
-                LOG.exception(_("Could not find module result in %s") %
+                LOG.exception("Could not find module result in %s",
                               result_file)
                 raise
         return result
@@ -185,7 +183,9 @@ class ModuleManager(object):
                     (is_admin or result.get('visible'))):
                 if include_contents:
                     codec = stream_codecs.Base64Codec()
-                    if not is_admin and result.get('admin_only'):
+                    # keep admin_only for backwards compatibility
+                    if not is_admin and (result.get('is_admin') or
+                                         result.get('admin_only')):
                         contents = (
                             "Must be admin to retrieve contents for module %s"
                             % result.get('name', 'Unknown'))
@@ -197,6 +197,7 @@ class ModuleManager(object):
                         result['contents'] = operating_system.read_file(
                             contents_file, codec=codec, decode=False)
                 results.append(result)
+        results.sort(key=operator.itemgetter('updated'), reverse=True)
         return results
 
     @classmethod
@@ -216,7 +217,7 @@ class ModuleManager(object):
                 name, datastore, ds_version, contents_file)
             cls.remove_module_result(module_dir)
         except Exception:
-            LOG.exception(_("Could not remove module '%s'") % name)
+            LOG.exception("Could not remove module '%s'", name)
             raise
         return removed, message
 
