@@ -16,7 +16,6 @@
 import abc
 import os
 import shlex
-import six
 from tempfile import NamedTemporaryFile
 import traceback
 
@@ -51,8 +50,7 @@ def log_and_raise(log_fmt, exc_fmt, fmt_content=None):
     raise exception.GuestError(original_message=raise_msg)
 
 
-@six.add_metaclass(abc.ABCMeta)
-class FSBase(object):
+class FSBase(object, metaclass=abc.ABCMeta):
 
     def __init__(self, fstype, format_options):
         self.fstype = fstype
@@ -71,7 +69,7 @@ class FSBase(object):
         """
 
     @abc.abstractmethod
-    def resize(self, device_path):
+    def resize(self, device_path, online=False):
         """
         Resize the filesystem on device
         """
@@ -113,9 +111,10 @@ class FSExt(FSBase):
             exc_fmt = _("Volume '%s' was not formatted.")
             log_and_raise(log_fmt, exc_fmt, device_path)
 
-    def resize(self, device_path):
-        utils.execute("e2fsck", "-f", "-p", device_path,
-                      run_as_root=True, root_helper="sudo")
+    def resize(self, device_path, online=False):
+        if not online:
+            utils.execute("e2fsck", "-f", "-p", device_path,
+                          run_as_root=True, root_helper="sudo")
         utils.execute("resize2fs", device_path,
                       run_as_root=True, root_helper="sudo")
 
@@ -158,7 +157,7 @@ class FSXFS(FSBase):
                 device_path)
             raise exception.GuestError(original_message=msg)
 
-    def resize(self, device_path):
+    def resize(self, device_path, online=False):
         utils.execute("xfs_repair", device_path,
                       run_as_root=True, root_helper="sudo")
         utils.execute("mount", device_path,
@@ -238,8 +237,14 @@ class VolumeDevice(object):
     def format(self):
         """Formats the device at device_path and checks the filesystem."""
         self._check_device_exists()
-        self._format()
-        self._check_format()
+
+        try:
+            self._check_format()
+            LOG.debug(f"Device {self.device_path} already formatted.")
+            return
+        except exception.GuestError:
+            self._format()
+            self._check_format()
 
     def mount(self, mount_point, write_to_fstab=True):
         """Mounts, and writes to fstab."""
@@ -263,18 +268,18 @@ class VolumeDevice(object):
 
         return True
 
-    def resize_fs(self, mount_point):
+    def resize_fs(self, mount_point, online=False):
         """Resize the filesystem on the specified device."""
         self._check_device_exists()
         # Some OS's will mount a file systems after it's attached if
         # an entry is put in the fstab file (like Trove does).
         # Thus it may be necessary to wait for the mount and then unmount
         # the fs again (since the volume was just attached).
-        if self._wait_for_mount(mount_point, timeout=2):
+        if not online and self._wait_for_mount(mount_point, timeout=2):
             LOG.debug("Unmounting '%s' before resizing.", mount_point)
             self.unmount(mount_point)
         try:
-            self.volume_fs.resize(self.device_path)
+            self.volume_fs.resize(self.device_path, online=online)
         except exception.ProcessExecutionError:
             log_fmt = "Error resizing the filesystem with device '%s'."
             exc_fmt = _("Error resizing the filesystem with device '%s'.")
@@ -335,7 +340,7 @@ class VolumeMountPoint(object):
     def mount(self):
         if not operating_system.exists(self.mount_point, is_directory=True,
                                        as_root=True):
-            operating_system.create_directory(self.mount_point, as_root=True)
+            operating_system.ensure_directory(self.mount_point, as_root=True)
         LOG.debug("Mounting volume. Device path:{0}, mount_point:{1}, "
                   "volume_type:{2}, mount options:{3}".format(
                       self.device_path, self.mount_point, self.volume_fstype,
