@@ -34,8 +34,8 @@ from trove.common import policy
 from trove.common import utils
 from trove.common import wsgi
 from trove.datastore import models as ds_models
-from trove.extensions.mysql.common import populate_users
-from trove.extensions.mysql.common import populate_validated_databases
+from trove.extensions.common.common import populate_users
+from trove.extensions.common.common import populate_validated_databases
 from trove.instance import models, views
 from trove.module import models as module_models
 from trove.module import views as module_views
@@ -311,8 +311,8 @@ class InstanceController(wsgi.Controller):
 
         nic['network_id'] = network_id
         nic.pop('net-id', None)
-
-        self._check_network_overlap(context, network_id, subnet_id)
+        if not CONF.network.network_isolation:
+            self._check_network_overlap(context, network_id, subnet_id)
 
     def _check_network_overlap(self, context, user_network=None,
                                user_subnet=None):
@@ -472,7 +472,9 @@ class InstanceController(wsgi.Controller):
             self._check_nic(context, nic)
 
         if locality:
-            locality_domain = ['affinity', 'anti-affinity']
+            locality_domain = [
+                'affinity', 'soft-affinity',
+                'anti-affinity', 'soft-anti-affinity']
             locality_domain_msg = ("Invalid locality '%s'. "
                                    "Must be one of ['%s']" %
                                    (locality,
@@ -502,7 +504,7 @@ class InstanceController(wsgi.Controller):
             if configuration_ref:
                 configuration_id = utils.get_id_from_href(configuration_ref)
                 return configuration_id
-            return ""
+            return None
 
     def _modify_instance(self, context, req, instance, **kwargs):
         if 'detach_replica' in kwargs and kwargs['detach_replica']:
@@ -510,7 +512,8 @@ class InstanceController(wsgi.Controller):
                 context, request=req)
             with StartNotification(context, instance_id=instance.id):
                 instance.detach_replica()
-        elif 'configuration_id' in kwargs:
+
+        if 'configuration_id' in kwargs:
             if kwargs['configuration_id']:
                 context.notification = (
                     notification.DBaaSInstanceAttachConfiguration(context,
@@ -525,7 +528,8 @@ class InstanceController(wsgi.Controller):
                                                                   request=req))
                 with StartNotification(context, instance_id=instance.id):
                     instance.detach_configuration()
-        elif 'datastore_version' in kwargs:
+
+        if 'datastore_version' in kwargs:
             datastore_version = ds_models.DatastoreVersion.load(
                 instance.datastore, kwargs['datastore_version'])
 
@@ -539,7 +543,8 @@ class InstanceController(wsgi.Controller):
             with StartNotification(context, instance_id=instance.id,
                                    datastore_version_id=datastore_version.id):
                 instance.upgrade(datastore_version)
-        elif 'access' in kwargs:
+
+        if 'access' in kwargs:
             instance.update_access(kwargs['access'])
 
     def update(self, req, id, body, tenant_id):
@@ -558,7 +563,7 @@ class InstanceController(wsgi.Controller):
 
         name = body['instance'].get('name')
         if ((name and len(body['instance'].keys()) > 2) or
-            (not name and len(body['instance'].keys()) >= 2)):
+                (not name and len(body['instance'].keys()) >= 2)):
             raise exception.BadRequest("Only one attribute (except 'name') is "
                                        "allowed to update.")
 
@@ -574,8 +579,9 @@ class InstanceController(wsgi.Controller):
         if detach_replica:
             args['detach_replica'] = detach_replica
 
+        args['configuration_id'] = None
         configuration_id = self._configuration_parse(context, body)
-        if configuration_id is not None:
+        if configuration_id:
             args['configuration_id'] = configuration_id
 
         if 'access' in body['instance']:
