@@ -14,20 +14,18 @@
 #    under the License.
 
 from oslo_log import log as logging
-import oslo_messaging as messaging
 from oslo_service import periodic_task
 from oslo_utils import importutils
 
 from trove.backup.models import Backup
 import trove.common.cfg as cfg
+from trove.common import clients
 from trove.common.context import TroveContext
 from trove.common import exception
 from trove.common.exception import ReplicationSlaveAttachError
 from trove.common.exception import TroveError
 from trove.common.i18n import _
 from trove.common.notification import DBaaSQuotas, EndNotification
-from trove.common import remote
-import trove.common.rpc.version as rpc_version
 from trove.common import server_group as srv_grp
 from trove.common.strategies.cluster import strategy
 from trove.datastore.models import DatastoreVersion
@@ -43,14 +41,12 @@ CONF = cfg.CONF
 
 class Manager(periodic_task.PeriodicTasks):
 
-    target = messaging.Target(version=rpc_version.RPC_API_VERSION)
-
     def __init__(self):
         super(Manager, self).__init__(CONF)
         self.admin_context = TroveContext(
-            user=CONF.nova_proxy_admin_user,
-            auth_token=CONF.nova_proxy_admin_pass,
-            tenant=CONF.nova_proxy_admin_tenant_id)
+            user_id=CONF.service_credentials.username,
+            project_id=CONF.service_credentials.project_id,
+            user_domain_name=CONF.service_credentials.user_domain_name)
         if CONF.exists_notification_transformer:
             self.exists_transformer = importutils.import_object(
                 CONF.exists_notification_transformer,
@@ -103,17 +99,32 @@ class Manager(periodic_task.PeriodicTasks):
                                        replica_models):
             # First, we transition from the old master to new as quickly as
             # possible to minimize the scope of unrecoverable error
+
+            # NOTE(zhaochao): we cannot reattach the old master to the new
+            # one immediately after the new master is up, because for MariaDB
+            # the other replicas are still connecting to the old master, and
+            # during reattaching the old master as a slave, new GTID may be
+            # created and synced to the replicas. After that, when attaching
+            # the replicas to the new master, 'START SLAVE' will fail by
+            # 'fatal error 1236' if the binlog of the replica diverged from
+            # the new master. So the proper order should be:
+            # -1. make the old master read only (and detach floating ips)
+            # -2. make sure the new master is up-to-date
+            # -3. detach the new master from the old one
+            # -4. enable the new master (and attach floating ips)
+            # -5. attach the other replicas to the new master
+            # -6. attach the old master to the new one
+            #     (and attach floating ips)
+            # -7. demote the old master
+            # What we changed here is the order of the 6th step, previously
+            # this step took place right after step 4, which causes failures
+            # with MariaDB replications.
             old_master.make_read_only(True)
-            master_ips = old_master.detach_public_ips()
-            slave_ips = master_candidate.detach_public_ips()
             latest_txn_id = old_master.get_latest_txn_id()
             master_candidate.wait_for_txn(latest_txn_id)
             master_candidate.detach_replica(old_master, for_failover=True)
             master_candidate.enable_as_master()
-            old_master.attach_replica(master_candidate)
-            master_candidate.attach_public_ips(master_ips)
             master_candidate.make_read_only(False)
-            old_master.attach_public_ips(slave_ips)
 
             # At this point, should something go wrong, there
             # should be a working master with some number of working slaves,
@@ -125,43 +136,60 @@ class Manager(periodic_task.PeriodicTasks):
                 try:
                     if replica.id != master_candidate.id:
                         replica.detach_replica(old_master, for_failover=True)
-                        replica.attach_replica(master_candidate)
+                        replica.attach_replica(master_candidate, restart=True)
                 except exception.TroveError as ex:
-                    msg = (_("Unable to migrate replica %(slave)s from "
-                             "old replica source %(old_master)s to "
-                             "new source %(new_master)s on promote.") %
-                           {"slave": replica.id,
-                            "old_master": old_master.id,
-                            "new_master": master_candidate.id})
-                    LOG.exception(msg)
-                    exception_replicas.append(replica)
-                    error_messages += "%s (%s)\n" % (msg, ex)
+                    log_fmt = ("Unable to migrate replica %(slave)s from "
+                               "old replica source %(old_master)s to "
+                               "new source %(new_master)s on promote.")
+                    exc_fmt = _("Unable to migrate replica %(slave)s from "
+                                "old replica source %(old_master)s to "
+                                "new source %(new_master)s on promote.")
+                    msg_content = {
+                        "slave": replica.id,
+                        "old_master": old_master.id,
+                        "new_master": master_candidate.id}
+                    LOG.error(log_fmt, msg_content)
 
+                    exception_replicas.append(replica)
+                    error_messages += "%s (%s)\n" % (
+                        exc_fmt % msg_content, ex)
+
+            # dealing with the old master after all the other replicas
+            # has been migrated.
+            old_master.attach_replica(master_candidate, restart=False)
             try:
                 old_master.demote_replication_master()
             except Exception as ex:
-                msg = (_("Exception demoting old replica source %s.") %
-                       old_master.id)
-                LOG.exception(msg)
+                log_fmt = "Exception demoting old replica source %s."
+                exc_fmt = _("Exception demoting old replica source %s.")
+                LOG.error(log_fmt, old_master.id)
                 exception_replicas.append(old_master)
-                error_messages += "%s (%s)\n" % (msg, ex)
+                error_messages += "%s (%s)\n" % (
+                    exc_fmt % old_master.id, ex)
 
             self._set_task_status([old_master] + replica_models,
                                   InstanceTasks.NONE)
+
             if exception_replicas:
                 self._set_task_status(exception_replicas,
                                       InstanceTasks.PROMOTION_ERROR)
                 msg = (_("promote-to-replica-source %(id)s: The following "
-                         "replicas may not have been switched: %(replicas)s") %
+                         "replicas may not have been switched: %(replicas)s:"
+                         "\n%(err)s") %
                        {"id": master_candidate.id,
-                        "replicas": [repl.id for repl in exception_replicas]})
-                raise ReplicationSlaveAttachError("%s:\n%s" %
-                                                  (msg, error_messages))
+                        "replicas": [repl.id for repl in exception_replicas],
+                        "err": error_messages})
+                raise ReplicationSlaveAttachError(msg)
+
+            LOG.info('Finished to promote %s as master.', instance_id)
 
         with EndNotification(context):
+            LOG.info('Promoting %s as replication master', instance_id)
+
             master_candidate = BuiltInstanceTasks.load(context, instance_id)
             old_master = BuiltInstanceTasks.load(context,
                                                  master_candidate.slave_of_id)
+
             replicas = []
             for replica_dbinfo in old_master.slaves:
                 if replica_dbinfo.id == instance_id:
@@ -186,6 +214,7 @@ class Manager(periodic_task.PeriodicTasks):
         return [[repl] + repl.get_last_txn() for repl in replica_models]
 
     def _most_current_replica(self, old_master, replica_models):
+        # last_txns is [instance, master UUID, last txn]
         last_txns = self._get_replica_txns(replica_models)
         master_ids = [txn[1] for txn in last_txns if txn[1]]
         if len(set(master_ids)) > 1:
@@ -199,14 +228,11 @@ class Manager(periodic_task.PeriodicTasks):
 
             master_candidate = self._most_current_replica(old_master,
                                                           replica_models)
+            LOG.info('New master selected: %s', master_candidate.id)
 
-            master_ips = old_master.detach_public_ips()
-            slave_ips = master_candidate.detach_public_ips()
             master_candidate.detach_replica(old_master, for_failover=True)
             master_candidate.enable_as_master()
-            master_candidate.attach_public_ips(master_ips)
             master_candidate.make_read_only(False)
-            old_master.attach_public_ips(slave_ips)
 
             exception_replicas = []
             error_messages = ""
@@ -216,15 +242,19 @@ class Manager(periodic_task.PeriodicTasks):
                         replica.detach_replica(old_master, for_failover=True)
                         replica.attach_replica(master_candidate)
                 except exception.TroveError as ex:
-                    msg = (_("Unable to migrate replica %(slave)s from "
-                             "old replica source %(old_master)s to "
-                             "new source %(new_master)s on eject.") %
-                           {"slave": replica.id,
-                            "old_master": old_master.id,
-                            "new_master": master_candidate.id})
-                    LOG.exception(msg)
+                    log_fmt = ("Unable to migrate replica %(slave)s from "
+                               "old replica source %(old_master)s to "
+                               "new source %(new_master)s on eject.")
+                    exc_fmt = _("Unable to migrate replica %(slave)s from "
+                                "old replica source %(old_master)s to "
+                                "new source %(new_master)s on eject.")
+                    msg_content = {
+                        "slave": replica.id,
+                        "old_master": old_master.id,
+                        "new_master": master_candidate.id}
+                    LOG.error(log_fmt, msg_content)
                     exception_replicas.append(replica)
-                    error_messages += "%s (%s)\n" % (msg, ex)
+                    error_messages += "%s (%s)\n" % (exc_fmt % msg_content, ex)
 
             self._set_task_status([old_master] + replica_models,
                                   InstanceTasks.NONE)
@@ -232,11 +262,14 @@ class Manager(periodic_task.PeriodicTasks):
                 self._set_task_status(exception_replicas,
                                       InstanceTasks.EJECTION_ERROR)
                 msg = (_("eject-replica-source %(id)s: The following "
-                         "replicas may not have been switched: %(replicas)s") %
+                         "replicas may not have been switched: %(replicas)s:"
+                         "\n%(err)s") %
                        {"id": master_candidate.id,
-                        "replicas": [repl.id for repl in exception_replicas]})
-                raise ReplicationSlaveAttachError("%s:\n%s" %
-                                                  (msg, error_messages))
+                        "replicas": [repl.id for repl in exception_replicas],
+                        "err": error_messages})
+                raise ReplicationSlaveAttachError(msg)
+
+            LOG.info('New master enabled: %s', master_candidate.id)
 
         with EndNotification(context):
             master = BuiltInstanceTasks.load(context, instance_id)
@@ -257,6 +290,10 @@ class Manager(periodic_task.PeriodicTasks):
                                                             instance_id)
             instance_tasks.migrate(host)
 
+    def rebuild(self, context, instance_id, image_id):
+        instance_tasks = models.BuiltInstanceTasks.load(context, instance_id)
+        instance_tasks.rebuild(image_id)
+
     def delete_instance(self, context, instance_id):
         with EndNotification(context):
             try:
@@ -283,7 +320,8 @@ class Manager(periodic_task.PeriodicTasks):
                                   datastore_manager, packages, volume_size,
                                   availability_zone, root_password, nics,
                                   overrides, slave_of_id, backup_id,
-                                  volume_type, modules):
+                                  volume_type, modules, access=None,
+                                  ds_version=None):
 
         if type(instance_id) in [list]:
             ids = instance_id
@@ -293,54 +331,70 @@ class Manager(periodic_task.PeriodicTasks):
             root_passwords = [root_password]
         replica_number = 0
         replica_backup_id = backup_id
-        replica_backup_created = False
         replicas = []
 
         master_instance_tasks = BuiltInstanceTasks.load(context, slave_of_id)
         server_group = master_instance_tasks.server_group
         scheduler_hints = srv_grp.ServerGroup.convert_to_hint(server_group)
-        LOG.debug("Using scheduler hints for locality: %s" % scheduler_hints)
+        LOG.debug("Using scheduler hints %s for creating instance %s",
+                  scheduler_hints, instance_id)
 
+        snapshot_driver = CONF.replica_snapshot_driver or CONF.storage_strategy
+
+        # Create backup for master
+        snapshot = None
+        try:
+            instance_tasks = FreshInstanceTasks.load(context, ids[0])
+            snapshot = instance_tasks.get_replication_master_snapshot(
+                context, slave_of_id, flavor,
+                parent_backup_id=replica_backup_id,
+                snapshot_driver=snapshot_driver)
+            LOG.info('Snapshot info for creating replica of %s: %s',
+                     slave_of_id, snapshot)
+        except Exception as err:
+            LOG.error('Failed to get master snapshot info for creating '
+                      'replica, error: %s', str(err))
+
+            if snapshot and snapshot.get('dataset', {}).get('snapshot_id'):
+                backup_id = snapshot['dataset']['snapshot_id']
+                Backup.delete(context, backup_id)
+
+            raise
+
+        # Create replicas using the master backup
+        replica_backup_id = snapshot['dataset']['snapshot_id']
         try:
             for replica_index in range(0, len(ids)):
-                try:
-                    replica_number += 1
-                    LOG.debug("Creating replica %d of %d."
-                              % (replica_number, len(ids)))
-                    instance_tasks = FreshInstanceTasks.load(
-                        context, ids[replica_index])
-                    snapshot = instance_tasks.get_replication_master_snapshot(
-                        context, slave_of_id, flavor, replica_backup_id,
-                        replica_number=replica_number)
-                    replica_backup_id = snapshot['dataset']['snapshot_id']
-                    replica_backup_created = (replica_backup_id is not None)
-                    instance_tasks.create_instance(
-                        flavor, image_id, databases, users, datastore_manager,
-                        packages, volume_size, replica_backup_id,
-                        availability_zone, root_passwords[replica_index],
-                        nics, overrides, None, snapshot, volume_type,
-                        modules, scheduler_hints)
-                    replicas.append(instance_tasks)
-                except Exception:
-                    # if it's the first replica, then we shouldn't continue
-                    LOG.exception(_(
-                        "Could not create replica %(num)d of %(count)d.")
-                        % {'num': replica_number, 'count': len(ids)})
-                    if replica_number == 1:
-                        raise
+                replica_number += 1
+                LOG.info(f"Creating replica {replica_number} "
+                         f"({ids[replica_index]}) of {len(ids)}.")
+
+                instance_tasks = FreshInstanceTasks.load(
+                    context, ids[replica_index])
+                instance_tasks.create_instance(
+                    flavor, image_id, databases, users, datastore_manager,
+                    packages, volume_size, replica_backup_id,
+                    availability_zone, root_passwords[replica_index],
+                    nics, overrides, None, snapshot, volume_type,
+                    modules, scheduler_hints, access=access,
+                    ds_version=ds_version)
+                replicas.append(instance_tasks)
 
             for replica in replicas:
                 replica.wait_for_instance(CONF.restore_usage_timeout, flavor)
-
+        except Exception as err:
+            LOG.error('Failed to create replica from %s, error: %s',
+                      slave_of_id, str(err))
+            raise
         finally:
-            if replica_backup_created:
-                Backup.delete(context, replica_backup_id)
+            Backup.delete(context, replica_backup_id)
 
     def _create_instance(self, context, instance_id, name, flavor,
                          image_id, databases, users, datastore_manager,
                          packages, volume_size, backup_id, availability_zone,
                          root_password, nics, overrides, slave_of_id,
-                         cluster_config, volume_type, modules, locality):
+                         cluster_config, volume_type, modules, locality,
+                         access=None, ds_version=None):
         if slave_of_id:
             self._create_replication_slave(context, instance_id, name,
                                            flavor, image_id, databases, users,
@@ -348,22 +402,31 @@ class Manager(periodic_task.PeriodicTasks):
                                            volume_size,
                                            availability_zone, root_password,
                                            nics, overrides, slave_of_id,
-                                           backup_id, volume_type, modules)
+                                           backup_id, volume_type, modules,
+                                           access=access,
+                                           ds_version=ds_version)
         else:
             if type(instance_id) in [list]:
                 raise AttributeError(_(
                     "Cannot create multiple non-replica instances."))
-            instance_tasks = FreshInstanceTasks.load(context, instance_id)
 
             scheduler_hints = srv_grp.ServerGroup.build_scheduler_hint(
-                context, locality, instance_id)
-            instance_tasks.create_instance(flavor, image_id, databases, users,
-                                           datastore_manager, packages,
-                                           volume_size, backup_id,
-                                           availability_zone, root_password,
-                                           nics, overrides, cluster_config,
-                                           None, volume_type, modules,
-                                           scheduler_hints)
+                context, locality, instance_id
+            )
+            LOG.debug("Using scheduler hints %s for creating instance %s",
+                      scheduler_hints, instance_id)
+
+            instance_tasks = FreshInstanceTasks.load(context, instance_id)
+            instance_tasks.create_instance(
+                flavor, image_id, databases, users,
+                datastore_manager, packages,
+                volume_size, backup_id,
+                availability_zone, root_password,
+                nics, overrides, cluster_config,
+                None, volume_type, modules,
+                scheduler_hints, access=access, ds_version=ds_version
+            )
+
             timeout = (CONF.restore_usage_timeout if backup_id
                        else CONF.usage_timeout)
             instance_tasks.wait_for_instance(timeout, flavor)
@@ -372,18 +435,24 @@ class Manager(periodic_task.PeriodicTasks):
                         image_id, databases, users, datastore_manager,
                         packages, volume_size, backup_id, availability_zone,
                         root_password, nics, overrides, slave_of_id,
-                        cluster_config, volume_type, modules, locality):
-        with EndNotification(context,
-                             instance_id=(instance_id[0]
-                                          if type(instance_id) is list
-                                          else instance_id)):
+                        cluster_config, volume_type, modules, locality,
+                        access=None, ds_version=None):
+        with EndNotification(
+            context,
+            instance_id=(
+                instance_id[0]
+                if isinstance(instance_id, list)
+                else instance_id
+            )
+        ):
             self._create_instance(context, instance_id, name, flavor,
                                   image_id, databases, users,
                                   datastore_manager, packages, volume_size,
                                   backup_id, availability_zone,
                                   root_password, nics, overrides, slave_of_id,
                                   cluster_config, volume_type, modules,
-                                  locality)
+                                  locality, access=access,
+                                  ds_version=ds_version)
 
     def upgrade(self, context, instance_id, datastore_version_id):
         instance_tasks = models.BuiltInstanceTasks.load(context, instance_id)
@@ -391,14 +460,15 @@ class Manager(periodic_task.PeriodicTasks):
         with EndNotification(context):
             instance_tasks.upgrade(datastore_version)
 
-    def update_overrides(self, context, instance_id, overrides):
+    def update_access(self, context, instance_id, access):
         instance_tasks = models.BuiltInstanceTasks.load(context, instance_id)
-        instance_tasks.update_overrides(overrides)
 
-    def unassign_configuration(self, context, instance_id, flavor,
-                               configuration_id):
-        instance_tasks = models.BuiltInstanceTasks.load(context, instance_id)
-        instance_tasks.unassign_configuration(flavor, configuration_id)
+        try:
+            instance_tasks.update_access(access)
+        except Exception as e:
+            LOG.error(f"Failed to update access configuration for "
+                      f"{instance_id}: {str(e)}")
+            self.update_db(task_status=InstanceTasks.UPDATING_ERROR_ACCESS)
 
     def create_cluster(self, context, cluster_id):
         with EndNotification(context, cluster_id=cluster_id):
@@ -406,18 +476,37 @@ class Manager(periodic_task.PeriodicTasks):
             cluster_tasks.create_cluster(context, cluster_id)
 
     def grow_cluster(self, context, cluster_id, new_instance_ids):
-        cluster_tasks = models.load_cluster_tasks(context, cluster_id)
-        cluster_tasks.grow_cluster(context, cluster_id, new_instance_ids)
+        with EndNotification(context, cluster_id=cluster_id,
+                             instance_ids=new_instance_ids):
+            cluster_tasks = models.load_cluster_tasks(context, cluster_id)
+            cluster_tasks.grow_cluster(context, cluster_id, new_instance_ids)
 
     def shrink_cluster(self, context, cluster_id, instance_ids):
+        with EndNotification(context, cluster_id=cluster_id,
+                             instance_ids=instance_ids):
+            cluster_tasks = models.load_cluster_tasks(context, cluster_id)
+            cluster_tasks.shrink_cluster(context, cluster_id, instance_ids)
+
+    def restart_cluster(self, context, cluster_id):
         cluster_tasks = models.load_cluster_tasks(context, cluster_id)
-        cluster_tasks.shrink_cluster(context, cluster_id, instance_ids)
+        cluster_tasks.restart_cluster(context, cluster_id)
+
+    def upgrade_cluster(self, context, cluster_id, datastore_version_id):
+        datastore_version = DatastoreVersion.load_by_uuid(datastore_version_id)
+        cluster_tasks = models.load_cluster_tasks(context, cluster_id)
+        cluster_tasks.upgrade_cluster(context, cluster_id, datastore_version)
 
     def delete_cluster(self, context, cluster_id):
         with EndNotification(context):
             cluster_tasks = models.load_cluster_tasks(context, cluster_id)
             cluster_tasks.delete_cluster(context, cluster_id)
 
+    def reapply_module(self, context, module_id, md5, include_clustered,
+                       batch_size, batch_delay, force):
+        models.ModuleTasks.reapply_module(
+            context, module_id, md5, include_clustered,
+            batch_size, batch_delay, force)
+
     if CONF.exists_notification_transformer:
         @periodic_task.periodic_task
         def publish_exists_event(self, context):
@@ -428,13 +517,14 @@ class Manager(periodic_task.PeriodicTasks):
             mgmtmodels.publish_exist_events(self.exists_transformer,
                                             self.admin_context)
 
-    @periodic_task.periodic_task(spacing=CONF.quota_notification_interval)
-    def publish_quota_notifications(self, context):
-        nova_client = remote.create_nova_client(self.admin_context)
-        for tenant in nova_client.tenants.list():
-            for quota in QUOTAS.get_all_quotas_by_tenant(tenant.id):
-                usage = QUOTAS.get_quota_usage(quota)
-                DBaaSQuotas(self.admin_context, quota, usage).notify()
+    if CONF.quota_notification_interval:
+        @periodic_task.periodic_task(spacing=CONF.quota_notification_interval)
+        def publish_quota_notifications(self, context):
+            nova_client = clients.create_nova_client(self.admin_context)
+            for tenant in nova_client.tenants.list():
+                for quota in QUOTAS.get_all_quotas_by_tenant(tenant.id):
+                    usage = QUOTAS.get_quota_usage(quota)
+                    DBaaSQuotas(self.admin_context, quota, usage).notify()
 
     def __getattr__(self, name):
         """
