@@ -16,9 +16,9 @@
 import jsonschema
 from testtools.matchers import Is
 
-from trove.extensions.mysql.service import SchemaController
-from trove.extensions.mysql.service import UserAccessController
-from trove.extensions.mysql.service import UserController
+from trove.extensions.common.service import SchemaController
+from trove.extensions.common.service import UserAccessController
+from trove.extensions.common.service import UserController
 from trove.tests.unittests import trove_testtools
 
 
@@ -30,17 +30,17 @@ class TestUserController(trove_testtools.TestCase):
     def test_get_create_schema(self):
         body = {'users': [{'name': 'test', 'password': 'test'}]}
         schema = self.controller.get_schema('create', body)
-        self.assertTrue('users' in schema['properties'])
+        self.assertIn('users', schema['properties'])
 
     def test_get_update_user_pw(self):
         body = {'users': [{'name': 'test', 'password': 'test'}]}
         schema = self.controller.get_schema('update_all', body)
-        self.assertTrue('users' in schema['properties'])
+        self.assertIn('users', schema['properties'])
 
     def test_get_update_user_db(self):
         body = {'databases': [{'name': 'test'}, {'name': 'test'}]}
         schema = self.controller.get_schema('update_all', body)
-        self.assertTrue('databases' in schema['properties'])
+        self.assertIn('databases', schema['properties'])
 
     def test_validate_create_empty(self):
         body = {"users": []}
@@ -62,7 +62,7 @@ class TestUserController(trove_testtools.TestCase):
         error_messages = [error.message for error in errors]
         error_paths = [error.path.pop() for error in errors]
         self.assertThat(len(errors), Is(2))
-        self.assertIn("'' is too short", error_messages)
+        self.assertIn("'' should be non-empty", error_messages)
         self.assertIn("'' does not match '^.*[0-9a-zA-Z]+.*$'", error_messages)
         self.assertIn("password", error_paths)
 
@@ -86,7 +86,7 @@ class TestUserController(trove_testtools.TestCase):
         error_paths = [error.path.pop() for error in errors]
         self.assertThat(len(errors), Is(3))
         self.assertIn("'password' is a required property", error_messages)
-        self.assertIn("'' is too short", error_messages)
+        self.assertIn("'' should be non-empty", error_messages)
         self.assertIn("'' does not match '^.*[0-9a-zA-Z]+.*$'", error_messages)
         self.assertIn("name", error_paths)
 
@@ -185,7 +185,7 @@ class TestUserController(trove_testtools.TestCase):
         error_messages = [error.message for error in errors]
         error_paths = [error.path.pop() for error in errors]
         self.assertThat(len(errors), Is(2))
-        self.assertIn("'' is too short", error_messages)
+        self.assertIn("'' should be non-empty", error_messages)
         self.assertIn("'' does not match '^.*[0-9a-zA-Z]+.*$'", error_messages)
         self.assertIn("password", error_paths)
 
@@ -199,7 +199,7 @@ class TestUserController(trove_testtools.TestCase):
         error_messages = [error.message for error in errors]
         error_paths = [error.path.pop() for error in errors]
         self.assertThat(len(errors), Is(2))
-        self.assertIn("'' is too short", error_messages)
+        self.assertIn("'' should be non-empty", error_messages)
         self.assertIn("'' does not match '^.*[0-9a-zA-Z]+.*$'", error_messages)
         self.assertIn("password", error_paths)
 
@@ -213,7 +213,7 @@ class TestUserController(trove_testtools.TestCase):
         error_messages = [error.message for error in errors]
         error_paths = [error.path.pop() for error in errors]
         self.assertThat(len(errors), Is(2))
-        self.assertIn("'' is too short", error_messages)
+        self.assertIn("'' should be non-empty", error_messages)
         self.assertIn("password", error_paths)
 
     def test_validate_update_no_password(self):
@@ -252,14 +252,14 @@ class TestUserController(trove_testtools.TestCase):
         error_paths = [error.path.pop() for error in errors]
         self.assertThat(len(errors), Is(3))
         self.assertIn("'password' is a required property", error_messages)
-        self.assertIn("'' is too short", error_messages)
+        self.assertIn("'' should be non-empty", error_messages)
         self.assertIn("'' does not match '^.*[0-9a-zA-Z]+.*$'", error_messages)
         self.assertIn("name", error_paths)
 
     def test_get_update_user_attributes(self):
         body = {'user': {'name': 'test'}}
         schema = self.controller.get_schema('update', body)
-        self.assertTrue('user' in schema['properties'])
+        self.assertIn('user', schema['properties'])
 
     def test_validate_update_user_attributes(self):
         body = {'user': {'name': 'test', 'password': 'test', 'host': '%'}}
@@ -337,7 +337,7 @@ class TestSchemaController(trove_testtools.TestCase):
 
     def test_validate_mixed(self):
         schema = self.controller.get_schema('create', self.body)
-        self.assertNotEqual(schema, None)
+        self.assertIsNotNone(schema)
         validator = jsonschema.Draft4Validator(schema)
         self.assertTrue(validator.is_valid(self.body))
 
@@ -345,14 +345,14 @@ class TestSchemaController(trove_testtools.TestCase):
         body = self.body.copy()
         body['databases'].append({"collate": "some_collation"})
         schema = self.controller.get_schema('create', body)
-        self.assertNotEqual(schema, None)
+        self.assertIsNotNone(schema)
         validator = jsonschema.Draft4Validator(schema)
         self.assertFalse(validator.is_valid(body))
 
     def test_validate_empty(self):
         body = {"databases": []}
         schema = self.controller.get_schema('create', body)
-        self.assertNotEqual(schema, None)
-        self.assertTrue('databases' in body)
+        self.assertIsNotNone(schema)
+        self.assertIn('databases', body)
         validator = jsonschema.Draft4Validator(schema)
         self.assertTrue(validator.is_valid(body))
